
USE DynamicsPerf

----------------------------------------------------------------
-- List top 100 most expensive queries
----------------------------------------------------------------

SELECT TOP 100 *
FROM   
	QUERY_STATS_CURR_VW  -- Queries from last data collection only
--    QUERY_STATS_VW  -- Review queries for all data collections


WHERE QUERY_HASH NOT IN (SELECT QUERY_HASH FROM QUERY_STATS WHERE COMMENT > '')
-- AND  QUERY_HASH = <QUERY_HASH>  -- find a specific query
-- AND SQL_TEXT LIKE '%VALUE%'  -- find all SQL statements that contain a specific text i.e. table name
-- AND LAST_EXECUTION_TIME > 'XXXXXXX'   -- find all queries that have executed after a specific time
-- AND DATABASE_NAME = 'XXXXXXXXX'       -- find all queries for a specific database
-- AND MAX_ELAPSED_TIME /10 > AVG_ELAPSED_TIME  -- Find all queries potentially getting blocked or paramater sniffing issues

ORDER  BY TOTAL_ELAPSED_TIME DESC  -- Queries consuming most TOTAL time on SQL Server
-- ORDER  BY AVG_LOGICAL_READS DESC  -- Queries potentially causing large disk i/o
-- ORDER  BY EXECUTION_COUNT DESC  -- High execution count could be loops in application code
-- ORDER  BY TOTAL_LOGICAL_READS DESC  -- Queries to review to potentially reduce disk i/o

----------------------------------------------------------------
-- Identify queries that the optimizer suspects can be optimized 
-- by new or changed indexes:
--
-- NOTE: DO NOT add these indexes verbatim without
--   deep analysis.  Large INCLUDED lists are NOT recommended
--   for ERP solutions
----------------------------------------------------------------

SELECT TOP 100 *
FROM   MISSING_INDEXES_CURR_VW

WHERE QUERY_HASH NOT IN (SELECT QUERY_HASH FROM QUERY_STATS WHERE COMMENT > '')
AND INDEX_IMPACT > 75 AND EXECUTION_COUNT>100 and AVG_ELAPSED_TIME > 20  AND AVG_LOGICAL_READS > 1000
ORDER  BY TOTAL_LOGICAL_READS DESC

-- --------------------------------------------------------------
-- Find long running queries from Dynamics AX with source code
-- requires client tracing being enabled on the AOS configuration
----------------------------------------------------------------

SELECT TOP 100 [CREATED_DATETIME],[DATABASE_NAME],[ROW_NUM], [AX_USER_ID], [SQL_DURATION], [SQL_TEXT], [CALL_STACK], [TRACE_CATEGORY], [TRACE_EVENT_CODE], [TRACE_EVENT_DESC], [TRACE_EVENT_DETAILS], [CONNECTION_TYPE], [SQL_SESSION_ID], [AX_CONNECTION_ID], [IS_LOBS_INCLUDED], [IS_MORE_DATA_PENDING], [ROWS_AFFECTED], [ROW_SIZE], [ROWS_PER_FETCH], [IS_SELECTED_FOR_UPDATE], [IS_STARTED_WITHIN_TRANSACTION], [SQL_TYPE], [STATEMENT_ID], [STATEMENT_REUSE_COUNT], [DETAIL_TYPE], [STATS_TIME], [COMMENT]
FROM   [AX_SQLTRACE]
ORDER  BY [CREATED_DATETIME] DESC 

----------------------------------------------------------------
--
-- List queries that have more than 1 execution plan
-- NOTE:  Only useful on SQL2008 or greater
-- This is for potential parameter sniffing issues
----------------------------------------------------------------

SELECT DATABASE_NAME, QUERY_HASH, COUNT(QUERY_PLAN_HASH) as CNT
FROM   QUERY_STATS_CURR_VW
GROUP BY DATABASE_NAME,QUERY_HASH
HAVING COUNT(QUERY_PLAN_HASH)>1
ORDER  BY CNT DESC

----------------------------------------------------------------
-- Find queries scanning a table
----------------------------------------------------------------

SELECT TOP 100 *
FROM   QUERY_STATS_CURR_VW
WHERE  ( QUERY_PLAN_TEXT LIKE '%TABLE SCAN%'
          OR QUERY_PLAN_TEXT LIKE '%CLUSTERED INDEX SCAN%' )
--AND QUERY_PLAN_TEXT LIKE '%<Table Name>%'  -- Comment this line to return all tables
ORDER  BY TOTAL_LOGICAL_READS DESC

-------------------------------------------------------------------------
-- Find queries option(fast) set that have sort operations
--  Dynamics AX only query
--
-- Either we don't have an index to match the order by clause
--  or the query is potentially to complex for SQL to pick that index
--------------------------------------------------------------------------

SELECT TOP 100 * FROM QUERY_STATS_CURR_VW
WHERE SQL_TEXT LIKE '%OPTION(FAST%' 
AND QUERY_PLAN_TEXT LIKE '%PhysicalOp="Sort"%'
ORDER BY TOTAL_ELAPSED_TIME DESC