
/*****************  CURRENT BLOCKING ***********************/
-- Use this query to review blocks that are occuring right now


USE DynamicsPerf
EXEC SP_LOGBLOCKS_MS




/*****************  HISTORICAL BLOCKING **********************************
* 
*
*  NOTE:DYNPERF_Default_Trace_Start Job MUST be setup and running
*
*
**************************************************************************/



/********* This view reads the Trace files direct 
***   from the @PATH parameter on the DYNPERF_Default_Trace_Start job  *******/


SELECT *
FROM   [BLOCKED_PROCESS_VW] 
ORDER BY END_TIME DESC




/******** Read the trace directly  *************/

SELECT E.name,
       F.*
--FROM fn_trace_gettable('C:\SQLTRACE\DYNAMICS_DEFAULT.trc', DEFAULT) F,
--sys.trace_events EXECUTE 
FROM   fn_trace_gettable(isnull((SELECT TRACE_FULL_PATH_NAME
                                 FROM   DYNAMICSPERF_SETUP), (SELECT TOP 1 path
                                                              FROM   sys.traces
                                                              WHERE  path LIKE '%DYNAMICS_DEFAULT%')), DEFAULT) F,
       sys.trace_events E
WHERE  EventClass = trace_event_id
ORDER  BY StartTime DESC 

      
      




--This Query loads the data from the Trace file into DynamicsPerf database manually
--Only inserts records since the last time this procedure was run, so no duplicates are created

EXEC SP_POPULATE_BLOCKED_PROCESS_INFO @TRACE_FULL_PATH_NAME = 'C:\SQLTRACE\DYNAMICS_DEFAULT.trc'


-- This query is used to review that data loaded from the SP_POPULATE_BLOCKED_PROCESS_INFO procedure
-- Review the files in the C:\SQLTRACE folder for further information such as Deadlock Graph events

SELECT *
FROM   [BLOCKED_PROCESS_INFO_VW]















/*********************  Queries to Investigate blocking using the DYNPERF_Optional_Polling_for_Blocking Job **********************************/


/**********************************************************************************************************
*
*
*
*  NOTE: The DYNPERF_Optional_Polling_for_Blocking must be run for any of the following queries to 
*			have data.  This job is not intended to run full time but only optionally when more 
*			information is needed for api_cursorfetch sql statements in blocking conditions.
*
*
*
**********************************************************************************************************/






/*************************************************************************
Find all lead blockers from most recent to oldest
*************************************************************************/
SELECT *
FROM   BLOCKS
WHERE  BLOCKER_STATUS = 'Lead Blocker'
ORDER  BY BLOCKED_DTTM DESC

/*************************************************************************
Find all lead blockers with a wait time > 2 seconds from most recent to oldest
*************************************************************************/
SELECT *
FROM   BLOCKS
WHERE  BLOCKER_STATUS = 'Lead Blocker'
       AND WAIT_TIME > 2000
ORDER  BY BLOCKED_DTTM DESC

/*************************************************************************
Find all lead blockers with a wait time > 2 seconds on a specific date
  from most recent to oldest
*************************************************************************/
SELECT *
FROM   BLOCKS
WHERE  BLOCKER_STATUS = 'Lead Blocker'
       AND WAIT_TIME > 2000
       AND BLOCKED_DTTM BETWEEN '5/20/2008' AND '5/21/2008'
ORDER  BY BLOCKED_DTTM DESC

/*************************************************************************
  Which applications are the Lead Blocker the most
  
*************************************************************************/
SELECT BLOCKER_PROGRAM,
       COUNT(*) AS NUMBER
FROM   BLOCKS
WHERE  BLOCKER_STATUS = 'Lead Blocker'
GROUP  BY BLOCKER_PROGRAM
ORDER  BY NUMBER DESC

/*************************************************************************
  Which applications are Blocked the most
  
*************************************************************************/
SELECT BLOCKED_PROGRAM,
       COUNT(*) AS NUMBER
FROM   BLOCKS
GROUP  BY BLOCKED_PROGRAM
ORDER  BY NUMBER DESC

/*************************************************************************
  Which applications are causing the most waiting
  
*************************************************************************/
SELECT BLOCKER_PROGRAM,
       SUM(WAIT_TIME) AS WAITTIME
FROM   BLOCKS
GROUP  BY BLOCKER_PROGRAM
ORDER  BY WAITTIME DESC

/*************************************************************************
  Which applications are waiting the most 
  
*************************************************************************/
SELECT BLOCKED_PROGRAM,
       SUM(WAIT_TIME) AS WAITTIME
FROM   BLOCKS
GROUP  BY BLOCKED_PROGRAM
ORDER  BY WAITTIME DESC

/*************************************************************************
  Which objects are waiting the most 
  
*************************************************************************/
SELECT OBJECT_NAME,
       SUM(WAIT_TIME) AS WAITTIME
FROM   BLOCKS
GROUP  BY OBJECT_NAME
ORDER  BY WAITTIME DESC

/*************************************************************************
  Which databases are waiting the most 
  
*************************************************************************/
SELECT DATABASE_NAME,
       SUM(WAIT_TIME) AS WAITTIME
FROM   BLOCKS
GROUP  BY DATABASE_NAME
ORDER  BY WAITTIME DESC
/******************************************************************************************/
