/**************  Hourly Change in Row Count by Table **************************************/


USE [DynamicsPerf]

--Hourly Totals
SELECT *
FROM   PERF_HOURLY_ROWDATA_VW
WHERE  ROWRANK = 9999
AND DATABASE_NAME <> 'NULL'
ORDER  BY STATS_TIME DESC 


--Activity by TABLE for a specific hour
------------------------------------------------
SELECT *
FROM   PERF_HOURLY_ROWDATA_VW
WHERE  STATS_TIME = '2011-09-21 10:00:00.000'
AND TABLE_NAME <> 'NULL'
ORDER  BY ROWRANK 



/**************  Hourly Change in Disk IO Stats by File **************************************/

SELECT *
FROM   PERF_HOURLY_IOSTATS_VW 
WHERE DATABASE_NAME= 'XXXXX'
ORDER BY STATS_TIME DESC, DATABASE_NAME, FILE_ID



/*********************************************************************************************
*	IO bottleneck : If Top 2 values for wait stats include IO, (ASYNCH_IO_COMPLETION,IO_COMPLETION,LOGMGR,,WRITELOG,PAGEIOLATCH_x_xxx) there is an IO bottleneck.
*	Blocking bottleneck: If top 2 wait_stats values include locking (LCK_M_BU, LCK_M_IS, LCK_M_IU, LCK_% ), there is a blocking bottleneck
*	Parallelism: Cxpacket waits > 5%
************************************************************************************************/


SELECT STATS_TIME, RANK , WAIT_TYPE, WAITING_TASKS_LAST_HOUR, WAIT_TIME_MS_LAST_HOUR
FROM PERF_HOURLY_WAITSTATS_VW
WHERE (WAIT_TYPE like 'PAGEIOLATCH_%'
or    WAIT_TYPE like 'ASYNCH_IO_COMPLETION%'
or    WAIT_TYPE like 'IO_COMPLETION%'
or      WAIT_TYPE like 'LOGMGR%'
or      WAIT_TYPE like 'WRITELOG%' )
and RANK < 3 and WAIT_TIME_MS_LAST_HOUR > 0




--Activity between 2 data collections to look at comparisons over a longer time period
--Find all run_names

SELECT RUN_NAME FROM STATS_COLLECTION_SUMMARY
ORDER BY STATS_TIME DESC

--Find record count and table size differences between the runs
--Can use this to accurately predict database growth
--NOTE only TOP 1000 tables are returned
--------------------------------------------------------------------------------

SELECT * FROM fn_dbstats('Oct 13 2011  7:34PM', 'Oct 13 2011  7:35PM')
ORDER BY DELTA_SIZEMB DESC


--Find record read/write and row count differences between the runs
-------------------------------------------------------------------

SELECT A.TABLE_NAME,
       B.ROW_COUNT - A.ROW_COUNT                       AS DELTA_IN_ROWS,
       B.TOTALREADOPERATIONS - A.TOTALREADOPERATIONS   AS DELTA_IN_READS,
       B.TOTALWRITEOPERATIONS - A.TOTALWRITEOPERATIONS AS DELTA_IN_WRITES
FROM   INDEX_OPS_VW A
       INNER JOIN INDEX_OPS_VW B
         ON A.TABLE_NAME = B.TABLE_NAME
         AND A.DATABASE_NAME = B.DATABASE_NAME
            AND A.RUN_NAME = 'Oct 13 2011  6:53PM'
            AND B.RUN_NAME = 'Oct 13 2011  7:20PM' 
ORDER BY 2 DESC



/**************  Hourly Change in SQL Server Wait Stats **************************************/


SELECT *
FROM   PERF_HOURLY_WAITSTATS_VW 
ORDER BY STATS_TIME DESC, RANK




/************ Comparison queries between different data captures ****************************/
/*					SQL2008 AND ABOVE ONLY !!!!!                 ****************************/


SELECT D1.RUN_NAME           AS RUN1,
       D2.RUN_NAME           AS RUN2,
       D1.SQL_TEXT,
       D1.QUERY_PLAN,
       D1.AVG_ELAPSED_TIME   AS RUN1_AVG_TIME,
       D2.AVG_ELAPSED_TIME   AS RUN2_AVG_TIME,
       D2.AVG_ELAPSED_TIME-D1.AVG_ELAPSED_TIME AS TIME_DIFF,
       D1.AVG_LOGICAL_READS  AS RUN1_READS,
       D2.AVG_LOGICAL_READS  AS RUN2_READS,
       D2.AVG_LOGICAL_READS-D1.AVG_LOGICAL_READS AS READS_DIFF,
       D1.AVG_LOGICAL_WRITES AS RUN1_WRITES,
       D2.AVG_LOGICAL_WRITES AS RUN2_WRITES,
       D2.AVG_LOGICAL_WRITES-D1.AVG_LOGICAL_WRITES AS WRITES_DIFF,
       D1.QUERY_HASH
FROM   QUERY_STATS_VW D1
       INNER JOIN QUERY_STATS_VW D2
         ON D1.QUERY_HASH = D2.QUERY_HASH
        AND D1.DATABASE_NAME = D2.DATABASE_NAME
WHERE  D1.QUERY_HASH <> 0x0000000000000000
       AND D1.RUN_NAME = 'Jun 28 2011  6:15PM'
       AND D2.RUN_NAME = 'Jun 29 2011  5:00PM'
ORDER  BY D2.AVG_ELAPSED_TIME - D1.AVG_ELAPSED_TIME 




