/*******************************************************************************************
*******************************!!!!!!!!!READ!!!!!!!!****************************************
Database Compression Analyzer v2.6
Written by:		Michael De Voe, PFE - Dynamics Premier
Last Updated:	March 24, 2011

FYI  Compression is only available on SQL 2008 and later and Enterprise Edition and higher.
		 
This script is presented "AS IS" and has no warrenties expressed or implied.

MAKE A BACK BEFORE DO ANY DATABASE COMPRESSION ACTIVITIES!!!!!
*******************************************************************************************
*******************************************************************************************/

--------------------------------------------------------------------------------------------
-----------------------Compression Savings Simulator----------------------------------------
--------------------------------------------------------------------------------------------
DECLARE @ROW_COUNT_THRESHOLD						INT;
DECLARE @PRCNT_READ_THRESHOLD_FOR_PAGE_COMPRESSION	DECIMAL(28,10);
DECLARE @MINUMIM_COMPRESSION_SAVINGS_PRCNT			DECIMAL (28,10);
DECLARE @PAGE_ROW_PRCNT_DELTA						DECIMAL(28,10);
DECLARE @END_SIMULATION_AND_MARK_TABLES				TINYINT;
DECLARE @USE_USERSPECIDIED_READ_PRCNT				TINYINT;
DECLARE @USERSPECIFIED_READ_PRCNT					DECIMAL (28,10);
DECLARE @SHOW_RAW_COMP_SIM_DATA						TINYINT;

--------------------------------------------------------------------------------------------------------------------------------------------------------------
-----------------************SET PARAMETERS FOR COMPRESSION SIMULATION**************--------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------
SET @ROW_COUNT_THRESHOLD						= 10000	--What is the minimum number of rows an index needs to have to be considered for compression?  
														--The Default is 10,000 rows	
 	 														
SET @MINUMIM_COMPRESSION_SAVINGS_PRCNT			= 10	--What is you minimum % savings threshold for considering an index for compression?
														--The default is atleast 10% Savings from either ROW or PAGE Compression
	
SET @PAGE_ROW_PRCNT_DELTA						= 10	--If the PAGE and ROW compression % savings are similar which one do use, what is you threshold?
														--If PAGE compression will only save you an additional 5 or 10% space savings over ROW why incur 
														--the added overhead of PAGE compression?
														--The default is 10%, so if PAGE compressionwillonly save an additional 10% or less over ROW use ROW

SET @END_SIMULATION_AND_MARK_TABLES				= 0		--When you have found the appropriate Compression thersholds that you will use for you deployment
														--set this parameter to 1 and re-run the simulation code and this will mark the appropriate indexes
														--with the appropriate level of compression based on your threshold.  This will allow the XXXXXX
														--script to compress the selected indexes based on the desired thresholds specified about.
														--The default is 0 or 'NO' which will cause this script to just run the simulations
														--DO NOT SET THIS UNTIL YOU ARE READY TO MARK THE INDEXES FOR COMPRESSION
														--IF YOU SET THIS TO '1' YOU MUST SET @PRCNT_READ_THRESHOLD_FOR_PAGE_COMPRESSION TO THE APPROPRIATE VALUE BEFOE
														--RUNNING THE SCRIPT 
														
SET @PRCNT_READ_THRESHOLD_FOR_PAGE_COMPRESSION	= 100	--After viewing the simulation results for 80%, 70%, and 60% and you are ready to mark the indexes 
														--for comprsssion enter you desired read percentage here. (80,70, or 60)
														--The default value is 1 (100%) read
														--DO NOT SET THIS UNTIL YOU ARE READY TO MARK THE INDEXES FOR COMPRESSION
																										
------------------------------------------------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------FOR ADVANCED USE ONLY-------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------------														
SET @USE_USERSPECIDIED_READ_PRCNT				= 0		--Advanced use only
														--This is disabled by default

SET @SHOW_RAW_COMP_SIM_DATA						= 0		--Advanced use only
														--This is disabled by default

SET @USERSPECIFIED_READ_PRCNT					= NULL	--Advanced use only
														--This is disabled by default
-------------------------------------------------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------------------------------------------

SET NOCOUNT ON

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[#COMPRESSION_SIMULATION]') AND type in (N'U'))
DROP TABLE [dbo].[#COMPRESSION_SIMULATION]
 
CREATE TABLE #COMPRESSION_SIMULATION
(
Table_Name				sysname,
Index_Name				sysname NULL, 
Index_Type				varchar(15),
Index_Id				int,
Row_Count				int,
Read_Prcnt				decimal(28,10),
Curr_Index_Size_KB		int,			
Size_With_ROW_Comp		decimal(28,10),
Space_Savings_with_ROW	decimal(28,10),
Size_With_PAGE_Comp		decimal(28,10),
Space_Savings_with_PAGE	decimal(28,10),
ROW_Comp_Sav_Prcnt		decimal(28,10),
PAGE_Comp_Sav_Prcnt		decimal(28,10)
)


INSERT #COMPRESSION_SIMULATION 
([Table_Name],[Index_Name],[Index_Type],[Index_Id],[Row_Count],[Read_Prcnt],[Curr_Index_Size_KB],
[Size_With_ROW_Comp],[Space_Savings_with_ROW],[Size_With_PAGE_Comp],[Space_Savings_with_PAGE],[ROW_Comp_Sav_Prcnt],[PAGE_Comp_Sav_Prcnt])

SELECT 
C.Table_Name,
C.Index_Name,
C.Index_Type, 
C.Index_ID,  
C.Row_Count, 
(ROUND(C.Percent_Scan,2)*100) AS [Read_Prcnt], 
(I.dpages*8) AS [Curr_Index_Size_KB], 
ROUND(((I.dpages*8)*(((C.Row_Compression_Savings_In_Percent-100)/100))*-1),-1) AS [Size_With_ROW_Comp],
ROUND(((I.dpages*8)-(((I.dpages*8)*(((C.Row_Compression_Savings_In_Percent-100)/100))*-1))),-1) AS [Space_Savings_with_ROW],
ROUND(((I.dpages*8)*(((C.Page_Compression_Savings_In_Percent-100)/100))*-1),-1) AS [Size_With_PAGE_Comp],
ROUND(((I.dpages*8)-(((I.dpages*8)*(((C.Page_Compression_Savings_In_Percent-100)/100))*-1))),-1) AS [Space_Savings_with_PAGE],
ROUND(C.Row_Compression_Savings_In_Percent,2) AS [ROW_Comp_Sav_Prcnt],
ROUND(C.Page_Compression_Savings_In_Percent,2) AS [PAGE_Comp_Sav_Prcnt]  
FROM Compression_Analysis C
JOIN SysIndexesU I ON I.Object_Id = C.ObjectID AND I.Index_Id = C.Index_ID  



IF @END_SIMULATION_AND_MARK_TABLES = 0
	BEGIN
PRINT'
Estimated Database Size with an Index Read Threshold of 80% and Higher and Selected Thresholds'

SELECT 
		SUM(CASE
			WHEN [Read_Prcnt] >= 80 AND ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) > @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_PAGE]
			END) AS Page_Comp_Space_Savings_KB,
			
		SUM(CASE
			WHEN [Read_Prcnt] < 80 OR ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) <= @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_ROW]
			END) AS Row_Comp_Space_Savings_KB
FROM #COMPRESSION_SIMULATION
WHERE Row_Count >= @ROW_COUNT_THRESHOLD
AND [PAGE_Comp_Sav_Prcnt] >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT  	
END;		

		
IF @END_SIMULATION_AND_MARK_TABLES = 0
	BEGIN
PRINT'
Estimated Database Size with an Index Read Threshold of 70% and Higher and Selected Thresholds'

SELECT 
		SUM(CASE
			WHEN [Read_Prcnt] >= 70 AND ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) > @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_PAGE]
			END) AS Page_Comp_Space_Savings_KB,
			
		SUM(CASE
			WHEN [Read_Prcnt] < 70 OR ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) <= @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_ROW]
			END) AS Row_Comp_Space_Savings_KB
FROM #COMPRESSION_SIMULATION	
WHERE Row_Count >= @ROW_COUNT_THRESHOLD
AND [PAGE_Comp_Sav_Prcnt] >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT  	
END;
	
IF @END_SIMULATION_AND_MARK_TABLES = 0
	BEGIN		
PRINT'
Estimated Database Size with an Index Read Threshold of 60% and Higher and Selected Thresholds'

SELECT 
		SUM(CASE
			WHEN [Read_Prcnt] >= 60 AND ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) > @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_PAGE]
			END) AS Page_Comp_Space_Savings_KB,
			
		SUM(CASE
			WHEN [Read_Prcnt] < 60 OR ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) <= @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_ROW]
			END) AS Row_Comp_Space_Savings_KB
FROM #COMPRESSION_SIMULATION	
WHERE Row_Count >= @ROW_COUNT_THRESHOLD
AND [PAGE_Comp_Sav_Prcnt] >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT  	
END;

IF @USERSPECIFIED_READ_PRCNT IS NOT NULL
	BEGIN
	PRINT'
	Estimated Database Size with an Index Read Threshold of "User Specified" and Higher and Selected Thresholds'

	SELECT 	
		SUM(CASE
			WHEN [Read_Prcnt] >= @USERSPECIFIED_READ_PRCNT AND ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) > @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_PAGE]
			END) AS Page_Comp_Space_Savings_KB,
			
		SUM(CASE
			WHEN [Read_Prcnt] < @USERSPECIFIED_READ_PRCNT OR ([PAGE_Comp_Sav_Prcnt]-[ROW_Comp_Sav_Prcnt]) <= @PAGE_ROW_PRCNT_DELTA THEN [Space_Savings_with_ROW]
			END) AS Row_Comp_Space_Savings_KB
	FROM #COMPRESSION_SIMULATION	
	WHERE Row_Count >= @ROW_COUNT_THRESHOLD
	AND [PAGE_Comp_Sav_Prcnt] >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT  		
	END;


IF @END_SIMULATION_AND_MARK_TABLES <> 0
	BEGIN
	PRINT'
	Marking Indexes for Compression'

	UPDATE Compression_Analysis 
	SET Script = 'R'
	WHERE Row_Count >= @ROW_COUNT_THRESHOLD 
	AND Page_Compression_Savings_In_Percent >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT
	AND	Percent_Scan < @PRCNT_READ_THRESHOLD_FOR_PAGE_COMPRESSION
	OR
	Row_Count >= @ROW_COUNT_THRESHOLD 
	AND Page_Compression_Savings_In_Percent >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT
	AND ([Page_Compression_Savings_In_Percent]-[Row_Compression_Savings_In_Percent]) <= @PAGE_ROW_PRCNT_DELTA


	UPDATE Compression_Analysis 
	SET Script = 'P'
	WHERE Row_Count >= @ROW_COUNT_THRESHOLD
	AND	Percent_Scan >= (@PRCNT_READ_THRESHOLD_FOR_PAGE_COMPRESSION/100)
	AND	Page_Compression_Savings_In_Percent >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT
	AND ([Page_Compression_Savings_In_Percent]-[Row_Compression_Savings_In_Percent]) > @PAGE_ROW_PRCNT_DELTA

	UPDATE Compression_Analysis
	SET Comp_Info = 
		CAST((	CAST(@ROW_COUNT_THRESHOLD AS NVARCHAR(20)) + 'RCT-' + 
				CAST(@PRCNT_READ_THRESHOLD_FOR_PAGE_COMPRESSION AS NVARCHAR(20)) + 'RPT-' + 
				CAST(@MINUMIM_COMPRESSION_SAVINGS_PRCNT AS NVARCHAR(20)) + 'MCSP-' + 
				CAST(@PAGE_ROW_PRCNT_DELTA AS NVARCHAR(20)) + 'PRD-' + 
				CAST(GETDATE() AS NVARCHAR(20))
		) AS NVARCHAR(100)) 
	
	PRINT'
	Complete'
	END;


IF @USE_USERSPECIDIED_READ_PRCNT <> 0
	BEGIN
	PRINT'
	Marking Indexes for Compression using "User Specified" read percentage'

	UPDATE Compression_Analysis 
	SET Script = 'R'
	WHERE Row_Count >= @ROW_COUNT_THRESHOLD 
	AND	Percent_Scan < @USERSPECIFIED_READ_PRCNT
	AND Page_Compression_Savings_In_Percent >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT
	OR
	Row_Count >= @ROW_COUNT_THRESHOLD 
	AND Page_Compression_Savings_In_Percent >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT
	AND ([Page_Compression_Savings_In_Percent]-[Row_Compression_Savings_In_Percent]) <= @PAGE_ROW_PRCNT_DELTA
	

	UPDATE Compression_Analysis 
	SET Script = 'P'
	WHERE Row_Count >= @ROW_COUNT_THRESHOLD
	AND	Percent_Scan >= @USERSPECIFIED_READ_PRCNT
	AND	Row_Compression_Savings_In_Percent >= @MINUMIM_COMPRESSION_SAVINGS_PRCNT
	AND ([Page_Compression_Savings_In_Percent]-[Row_Compression_Savings_In_Percent]) > @PAGE_ROW_PRCNT_DELTA
	
	
	PRINT'
	Complete'
	END;

	PRINT'Script 1.2 Completed, Run Script 1.3
	'

IF @SHOW_RAW_COMP_SIM_DATA <> 0
	BEGIN
	PRINT'
	Raw Compression Simulation Data'
	
	select * from #COMPRESSION_SIMULATION
	END;

DROP TABLE #COMPRESSION_SIMULATION
GO