
USE DynamicsPerf

-- --------------------------------------------------------------
-- Is Enable X++ Debug enabled on any AOS Servers.
-- 20% decline in transactions processed on the AOS instances with this enabled
-----------------------------------------------------------------
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'xppdebug'
AND SETTING_VALUE <> '0'

-- --------------------------------------------------------------
-- Is Context_Info enabled on any AOS Servers.
-- 
-----------------------------------------------------------------
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'connectioncontext'
AND SETTING_VALUE <> '0'



-- --------------------------------------------------------------
-- Find tables that have entire table cache enabled that are larger than 128K
-- Causes the cache to overflow to disk on the AOS Server
-----------------------------------------------------------------

SELECT A.TABLE_NAME, APPLICATION_LAYER, CACHE_LOOKUP, PAGE_COUNT
FROM	AX_TABLE_DETAIL_CURR_VW A,
		INDEX_STATS_CURR_VW I
WHERE	A.DATABASE_NAME = I.DATABASE_NAME
AND		A.TABLE_NAME = I.TABLE_NAME
AND		CACHE_LOOKUP = 'EntireTable'
AND		(INDEX_DESCRIPTION  = 'HEAP' OR INDEX_DESCRIPTION LIKE ' CLUSTERED%')
AND		PAGE_COUNT > 16
ORDER BY PAGE_COUNT DESC

-- --------------------------------------------------------------
-- Find tables that have entire table cache and show update rate
-- Causes the cache to be refreshed on all AOS instances
-----------------------------------------------------------------
SELECT A.TABLE_NAME, APPLICATION_LAYER, CACHE_LOOKUP, USER_UPDATES
FROM	AX_TABLE_DETAIL_CURR_VW A,
		INDEX_STATS_CURR_VW I
WHERE	A.DATABASE_NAME = I.DATABASE_NAME
AND		A.TABLE_NAME = I.TABLE_NAME
AND		CACHE_LOOKUP = 'EntireTable'
AND		(INDEX_DESCRIPTION  = 'HEAP' OR INDEX_DESCRIPTION LIKE ' CLUSTERED%')
ORDER BY USER_UPDATES DESC


-- --------------------------------------------------------------
-- Find Dynamics AX queries that only seek on DataAreaId
-- NOT USEFUL for other products
-----------------------------------------------------------------


SELECT TOP 100 *
FROM   HIDDEN_SCANS_CURR_VW
ORDER  BY TOTAL_ELAPSED_TIME DESC

-- --------------------------------------------------------------
-- Find Dynamics queries that are scanning 
-----------------------------------------------------------------

SELECT TOP 100 *
FROM   USER_SCANS_CURR_VW
ORDER  BY TOTAL_ELAPSED_TIME DESC

-- --------------------------------------------------------------
-- Review number sequence configuration in Dynamics AX 
-----------------------------------------------------------------

SELECT *
  FROM AX_NUM_SEQUENCES_CURR_VW
  WHERE CONTINUOUS =0

-- -----------------------------------------------------------------------------
-- List BATCHGROUP configuration in Dynamics AX
--------------------------------------------------------------------------------

SELECT *
  FROM AX_BATCH_CONFIGURATION_VW

-- -----------------------------------------------------------------------------
-- List AOS cluster configuration in Dynamics AX
--------------------------------------------------------------------------------

SELECT *
  FROM AX_SERVER_CONFIGURATION_VW

-- --------------------------------------------------------------
-- List top 200 tables be logged in Dynamics AX
-- NOTE: if this query returns zero rows 
--         the AOTEXPORT class has not been run
-----------------------------------------------------------------

SELECT [TABLE_NAME],
       [ROWS_LOGGED],
       [DATABASELOG_UPDATE],
       [DATABASELOG_DELETE],
       [DATABASELOG_INSERT]
FROM   [AX_DATABASELOGGING_VW]
ORDER  BY [ROWS_LOGGED] DESC

-- -----------------------------------------------------------------------------
-- List NUMBERSEQUENCE table configuration in Dynamics AX
-- Are sequences marked as Coninuous?  If so why?
-- Is FETCHAHEADQTY > 0,  if not preallocation is not setup for this sequence 
-- Pre-allocation requires knowledge of the avg. number of numbers consumed 
-- per user process to determine a good value.        
--------------------------------------------------------------------------------

SELECT RUN2.[DATABASE_NAME],
       RUN2.[DATAAREAID],
       RUN2.[NUMBERSEQUENCE],
       RUN2.[TXT],
       Datediff(hh, RUN1.STATS_TIME, RUN2.STATS_TIME)                                       AS ELAPSED_HOURS,
       RUN2.NEXTREC - RUN1.NEXTREC                                                          AS TOTAL_NUMBERS_CONSUMED,
       ( RUN2.NEXTREC - RUN1.NEXTREC ) / ( Datediff(hh, RUN1.STATS_TIME, RUN2.STATS_TIME) ) AS HOURLY_CONSUMPTION_RATE,
       RUN2.[FORMAT],
       RUN2.[CONTINUOUS],
       RUN2.[FETCHAHEAD],
       RUN2.[FETCHAHEADQTY]
FROM   AX_NUM_SEQUENCES_VW RUN1
       INNER JOIN AX_NUM_SEQUENCES_VW RUN2
         ON RUN1.NUMBERSEQUENCE = RUN2.NUMBERSEQUENCE
            AND RUN1.DATAAREAID = RUN2.DATAAREAID
WHERE  RUN1.RUN_NAME = 'Oct  8 2011  1:19AM'
       AND RUN2.RUN_NAME = 'Oct 10 2011  4:08PM'
ORDER  BY 6 DESC 


--To find run_name run the following query


SELECT * FROM STATS_COLLECTION_SUMMARY 
ORDER BY STATS_TIME DESC


GO

/*************************************************************
*    Try to find the table where the sequence is being used  *
**************************************************************/
SELECT *
FROM   QUERY_STATS_CURR_VW
WHERE  QUERY_PLAN_TEXT LIKE '%XXXXXXX%' 
  --Use the format column from the usage query
