/* Query Example using the DATA_PURGE objects */
/*
Select * from DATA_PURGE_VW D
JOIN
(
SELECT TOP 25
	IND.TABLE_NAME AS [TABLE NAME], IND.ROW_COUNT AS [ROW COUNT]
	, TOT.TOTAL_TABLE_AND_INDEX_SIZE_MB AS [TOTAL SIZE MB]
	-- , TOT.TOTAL_INDEX_AND_DATA_PAGES AS [TOTAL PAGES]
FROM INDEX_STATS_CURR_VW IND
JOIN
(SELECT TABLE_NAME, SUM(PAGE_COUNT) AS TOTAL_INDEX_AND_DATA_PAGES, 
	((SUM(PAGE_COUNT) * 8)/1024) AS TOTAL_TABLE_AND_INDEX_SIZE_MB 
	FROM INDEX_STATS_CURR_VW 
	GROUP BY TABLE_NAME
	) TOT
ON IND.TABLE_NAME = TOT.TABLE_NAME
WHERE (IND.INDEX_DESCRIPTION LIKE 'CLUSTERED%' OR IND.INDEX_DESCRIPTION LIKE 'HEAP%')
--ORDER BY ROW_COUNT DESC
 ORDER BY TOT.TOTAL_TABLE_AND_INDEX_SIZE_MB DESC ) L
 ON D.Table_Name = L.[TABLE NAME]
WHERE D.AX_Version = 'AX2009' 
*/


USE [DynamicsPerf]
GO


/****** Object:  Table [dbo].[DATA_PURGE_PATH]   ******/
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[DATA_PURGE_PATH]') AND type in (N'U'))
DROP TABLE [dbo].[DATA_PURGE_PATH]
GO

/****** Object:  Table [dbo].[DATA_PURGE_PATH]    Script Date: 05/13/2012 12:01:35 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

SET ANSI_PADDING ON
GO


---------------------------------------------------------------------------------------------------------------
-- DATA_PURGE_PATH  Table
---------------------------------------------------------------------------------------------------------------
 -- The Path Name indicates a the Menu in AX  where Purge Class is called.
 -- It belongs to an AX Module.
---------------------------------------------------------------------------------------------------------------

CREATE TABLE [dbo].[DATA_PURGE_PATH](
	[AX_Version] varchar(10) NOT NULL,
	[Module_Name] [sysname] NOT NULL,
	[Path_Name] varchar(256) NOT NULL
) ON [PRIMARY]

GO

SET ANSI_PADDING OFF
GO

USE [DynamicsPerf]
GO

/****** Object:  Table [dbo].[DATA_PURGE_TABLE]    Script Date: 05/13/2012 12:07:16 ******/
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[DATA_PURGE_TABLE]') AND type in (N'U'))
DROP TABLE [dbo].[DATA_PURGE_TABLE]
GO

USE [DynamicsPerf]
GO

/****** Object:  Table [dbo].[DATA_PURGE_TABLE]    Script Date: 05/13/2012 12:07:16 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

SET ANSI_PADDING ON
GO

---------------------------------------------------------------------------------------------------------------
-- DATA_PURGE_TABLE  Table
---------------------------------------------------------------------------------------------------------------
 
 -- A Table can have several Purge clases 
 -- A Table can have several Path
---------------------------------------------------------------------------------------------------------------

CREATE TABLE [dbo].[DATA_PURGE_TABLE](
	[AX_Version] varchar(10) NOT NULL,
	[Table_Name] [sysname] NOT NULL,
	[Path_Name] varchar(256) NOT NULL,
	[Class_Name] varchar(256) NOT NULL,
	[Description] [varchar](max) NULL
) ON [PRIMARY]

GO

SET ANSI_PADDING OFF
GO



/****** Object:  Table [dbo].[DATA_PURGE_CLASS]    ******/
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[DATA_PURGE_CLASS]') AND type in (N'U'))
DROP TABLE [dbo].[DATA_PURGE_CLASS]
GO

/****** Object:  Table [dbo].[DATA_PURGE_CLASS]    Script Date: 05/13/2012 11:57:11 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

SET ANSI_PADDING ON
GO

---------------------------------------------------------------------------------------------------------------
-- DATA_PURGE_CLASS Table
---------------------------------------------------------------------------------------------------------------

--  The Class indicates the Dynamics AX Class instantiating the Purge.
--  The Description gives information about what the class does and when a user should call it (via the Path)
-- When the Purge Class doesn't exist, the name of the class starts with the prefix "Description"
 -- In that case, you can refer to the Page Number for further detailed description.
 
CREATE TABLE [dbo].[DATA_PURGE_CLASS](
	[AX_Version] varchar(10) NOT NULL,
	[Class_Name] varchar(256) NOT NULL,
	[page] [smallint] NULL,
	[Description] [varchar](max) NULL
) ON [PRIMARY]

GO

SET ANSI_PADDING OFF
GO


/****** Object:  View [dbo].[DATA_PURGE_VW]    Script Date: 05/13/2012 12:11:27 ******/
IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[DATA_PURGE_VW]'))
DROP VIEW [dbo].[DATA_PURGE_VW]
GO


/****** Object:  View [dbo].[DATA_PURGE_VW]    Script Date: 05/13/2012 12:11:27 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE VIEW [dbo].[DATA_PURGE_VW] AS

select P.AX_Version, Module_name, P.Path_Name, Table_Name, T.Class_Name, page, C.Description
from DATA_PURGE_PATH P
JOIN
DATA_PURGE_TABLE T  on P.Path_Name = T.Path_Name and P.AX_Version=T.AX_Version
JOIN
DATA_PURGE_CLASS C on T.Class_Name = C.Class_Name and T.AX_Version = C.AX_Version

GO


---------------------------------------------
-- Initialization of DATA_PURGE_PATH
---------------------------------------------
 
insert into DATA_PURGE_PATH (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'General Ledgger', 'General Ledger | Periodic | Clean up | Ledger journals clean up');
							 
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Accounts Receivable', 'Accounts Receivable | Periodic | Clean up | Sales update history clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Accounts Receivable', 'Accounts Receivable | Periodic | Clean up | Order entry statistics clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Accounts Receivable', 'Account Receivable | Setup | Parameters | Update |Delete order line invoiced in total & Delete order after invoicing');


insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Accounts Payable', 'Accounts Payable | Periodic | Clean up| Purchase update history clean up')
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Accounts Payable', 'Account Payable | Setup | Parameters | Update |Delete purchase order line invoiced in total & Delete purchase after invoicing')

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Inventory Management', 'Inventory Management | Periodic | Clean up | Inventory journals clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Inventory Management', 'Inventory Management | Periodic | Clean up | Inventory settlements clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Inventory Management', 'Inventory Management |Script');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Master Planning', 'Master Planning | Periodic\Master scheduling\Master plan');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Production', 'Production | Periodic | Clean up | Production orders clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Production', 'Production | Periodic | Clean up | Production journals clean up');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Shop floor control', 'Shop Floor Control | Periodic | Cleanup | Clean up registrations');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Human resources', 'Human resources | Periodic | Clean up | Delete absence journals');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Human resources', 'Human resources | Periodic | Clean up | Delete actions');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Human resources', 'Human resources | Periodic | Clean up | Delete personal information on employee');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Human resources', 'Human resources | Periodic | Clean up | Delete personal information on applicant');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Questionnaire', 'Questionnaire | Periodic | Delete results');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Project', 'Project | Periodic | Clean up | Project journals clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Project', 'Project | Periodic | Budget | Delete budget');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Project', 'Project | Periodic | Estimate | Delete');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Project', 'Project | Periodic | Quotation update | Delete quotations');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Service', 'Service | Periodic | Delete service orders');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Basic', 'Basic | Periodic | Calendar cleanup');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Basic', 'Basic | Periodic | Calendar cleanup');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Basic', 'Basic | Inquiries| Batch list | Functions | Delete');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Basic', 'Basic | Inquiries | Batch list | Functions | Clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Basic', 'Basic | Periodic | Application Integration Framework | Document History | Clear Document History | Clear document XML');

insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Administration', 'Administration | Inquiries | User log | Clean up');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Administration', 'Administration | Inquiries | Database log | Clean up log');
insert into DATA_PURGE_PATH  (AX_VERSION, MODULE_NAME, PATH_NAME) values ('AX2009', 'Administration', 'Administration | Inquiries | Database | SQL Statement Trace Log | Functions | Clear log');



---------------------------------------------
-- Initialization of DATA_PURGE_CLASS
---------------------------------------------

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\LedgerJournalCleanUp', 7, 'Use the Ledger journals Clean up process to delete posted ledger journals. Deleting journals will help make system resources available when you upgrade from a previous version of Microsoft Dynamics AX.  When a check box is selected, all the posted journals of the selected type are deleted. 
Ledger journals include journals in the Accounts receivable, Accounts payable, and Project modules.  You can delete inventory journals in the Inventory delete journals form (e.g., Inventory management | Periodic | Clean up | Inventory journals clean up).
');
insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\SalesParmCleanUp', 9, 'Use the Sales update history clean up process to delete old update history.  It is especially useful in connection with upgrading from previous versions of Microsoft Dynamics AX, because deleting the history of updates is less demanding on system resources.  When a Sales order is updated such as a confirmation, picking list, packing slip, or invoice the information is stored and tracked in the SALESPARMTABLE, SALESPARMUPDATE, SALESPARMSUBTABLE, and SALESPARMLINE tables. 
There are two options for clean up for the history of updates, 1) Executed, and 2) Executed and erroneous.  There is no option to clean up Erroneous updates only.   The difference between the two is found in the delete statement that is run against the SALESPARMTABLE.  Below are the delete statements that are run with each option listed below.  

EXECUTED
DELETE FROM SALESPARMTABLE WHERE ((DATAAREAID=?) AND ((CREATEDDATE<=?) AND (PARMJOBSTATUS=?))) [ID=53, Reused=No]

DELETE FROM SALESPARMUPDATE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM SALESPARMTABLE B WHERE ((B.DATAAREAID=?) AND (SALESPARMUPDATE.PARMID=B.PARMID))) [ID=54, Reused=No]

DELETE FROM SALESPARMSUBTABLE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM SALESPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((SALESPARMSUBTABLE.PARMID=B.PARMID) AND (SALESPARMSUBTABLE.SALESID=B.SALESID)))) [ID=55, Reused=No]

DELETE FROM SALESPARMLINE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM SALESPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((SALESPARMLINE.PARMID=B.PARMID) AND (SALESPARMLINE.SALESID=B.SALESID)))) [ID=56, Reused=No]

EXECUTED AND ERRONEOUS

DELETE FROM SALESPARMTABLE WHERE ((DATAAREAID=?) AND ((CREATEDDATE<=?) AND ((PARMJOBSTATUS=?) OR (PARMJOBSTATUS=?)))) [ID=11, Reused=No]

DELETE FROM SALESPARMUPDATE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM SALESPARMTABLE B WHERE ((B.DATAAREAID=?) AND (SALESPARMUPDATE.PARMID=B.PARMID))) [ID=12, Reused=No]

DELETE FROM SALESPARMSUBTABLE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM SALESPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((SALESPARMSUBTABLE.PARMID=B.PARMID) AND (SALESPARMSUBTABLE.SALESID=B.SALESID)))) [ID=13, Reused=No]

DELETE FROM SALESPARMLINE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM SALESPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((SALESPARMLINE.PARMID=B.PARMID) AND (SALESPARMLINE.SALESID=B.SALESID)))) [ID=14, Reused=No]
'
);

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\SalesOrderEntryStatisticsCleanUp', 9, 'Use the Order entry statistics clean up process to delete order entry statistics that are no longer needed. 
Tracking sales order entry statistics increases the amount of space required for data storage. It is a good idea to periodically remove sales order entry statistics that you no longer need to keep. 

1.	Click Accounts receivable > Periodic > Clean up > Order entry statistics clean up. 
2.	In the Created until field, select the last date on which statistic lines should be deleted. 
3.	Click OK. 
');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', 'Description_SalesLine', 9, 'There are other means to reducing the size of your data in Accounts receivable.  In the Accounts Receivable parameters you can choose to delete invoiced orders or invoiced order lines from the SALESLINE and SALESTABLE.   The sales order will be deleted right after the update of the invoice. You can still find the financial details on the customer and in the General Ledger. 
 
To remove records from the SALESLINE table at invoicing you would want to mark the option Delete order line invoiced in total.   Once a Sales Order line is invoiced you will no longer have a record in the SALESLINE table.  When the record is posted the INVENTTRANS record for the line is updated with an Invoiced status and will be the record that is maintained in the system.  

To remove record from the SALESTABLE you would want to mark the option Delete order after invoicing.  When you invoice update a Sales Order you will no longer have a record of the Sales Order in the SALESTABLE.  

The important thing to remember if you choose to use these options is that you will not have the ability to drill-down to the Sales Order from an Inventory, Ledger, or Customer transaction.  
');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\PurchParmCleanUp', 11, 'Use the Purchase update history clean up process to delete old update history.  It is especially useful in connection with upgrading from previous versions of Microsoft Dynamics AX, because deleting the history of updates is less demanding on system resources.  When a Purchase order is updated such as a confirmation, picking list, packing slip, or invoice, the information is stored and tracked in the PURCHPARMTABLE, PURCHPARMUPDATE, PURCHPARMSUBTABLE, and PURCHPARMLINE tables. 
There are two options for clean up for the history of updates, 1) Executed, and 2) Executed and erroneous.  There is no option to clean up Erroneous updates only.   The difference between the two is found in the delete statement that is run against the PURCHPARMTABLE.  Below are the delete statements that are run with each option listed below.  

EXECUTED
DELETE FROM PURCHPARMTABLE WHERE ((DATAAREAID=?) AND ((CREATEDDATE<=?) AND (PARMJOBSTATUS=?))) [ID=53, Reused=No]

DELETE FROM PURCHPARMUPDATE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM PURCHPARMTABLE B WHERE ((B.DATAAREAID=?) AND (PURCHPARMUPDATE.PARMID=B.PARMID))) [ID=54, Reused=No]

DELETE FROM PURCHPARMSUBTABLE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM PURCHPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((PURCHPARMSUBTABLE.PARMID=B.PARMID) AND (PURCHPARMSUBTABLE.PURCHID=B.PURCHID)))) [ID=55, Reused=No]

DELETE FROM PURCHPARMLINE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM PURCHPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((PURCHPARMLINE.PARMID=B.PARMID) AND (PURCHPARMLINE.PURCHID=B.PURCHID)))) [ID=56, Reused=No]

EXECUTED AND ERRONEOUS

DELETE FROM PURCHPARMTABLE WHERE ((DATAAREAID=?) AND ((CREATEDDATE<=?) AND ((PARMJOBSTATUS=?) OR (PARMJOBSTATUS=?)))) [ID=11, Reused=No]

DELETE FROM PURCHPARMUPDATE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM PURCHPARMTABLE B WHERE ((B.DATAAREAID=?) AND (PURCHPARMUPDATE.PARMID=B.PARMID))) [ID=12, Reused=No]

DELETE FROM PURCHPARMSUBTABLE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM PURCHPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((PURCHPARMSUBTABLE.PARMID=B.PARMID) AND (PURCHPARMSUBTABLE.PURCHID=B.PURCHID)))) [ID=13, Reused=No]

DELETE FROM PURCHPARMLINE WHERE (DATAAREAID=?) AND NOT EXISTS (SELECT ''x'' FROM PURCHPARMTABLE B(NOLOCK)  WHERE ((B.DATAAREAID=?) AND ((PURCHPARMLINE.PARMID=B.PARMID) AND (PURCHPARMLINE.PURCHID=B.PURCHID)))) [ID=14, Reused=No]

');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', 'Description_PurchLine', 12, 'There are other means to reducing the size of your data in Accounts payable.  In the Accounts Payable parameters you can choose to delete purchase order lines that are fully invoiced.  

If you have selected the Mark purchase as voided check box on the General tab and you select the Delete purchase order line invoiced in total check box, fully invoiced purchase lines are NOT deleted, but are marked as voided.  

By selecting the Delete purchase after invoicing option, you are able to delete the purchase order header when all the purchase order lines are deleted.  For the deletion to occur, the Delete purchase order line invoiced in total check box must also be selected.  

If the Mark the Purchase as voided check box on the General tab, the purchase order header is not deleted, but is marked as voided.  For the header to be marked as voided, the Delete purchase order line invoiced in total check box must also be selected.   When a PO is already posted and you delete a line, the values will stay posted but the line would not be available to see in the orders form.
');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\InventJournalCleanUp', 13, 'Use the Inventory journals clean up process to delete old inventory journals.  This process will delete all of the selected inventory journal types where Posted = Yes regardless of the date.  This process is especially useful in connection with upgrading from previous versions of Microsoft Dynamics AX, as deleting old inventory journals is less demanding on system resources.  The relevant records in the INVENTJOURNALTABLE are deleted as well as the corresponding transactions in the INVENTJOURNALTRANS tables.');


insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\InventCostCleanUp', 13, 'Use the Inventory settlements clean up process to delete old and cancelled inventory settlements.  The INVENTSETTLEMENT table can become quite large if youve cancelled inventory closes.  This can have an impact on performance.   

When closing Inventory using the Average cost model, the number of inventory settlement transactions can grow rapidly due to the fact that all settlement fragments generate a record in the settlement table.  
');


insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', 'Description_BOMCalcTable and BOMCalcTrans', 16, 'See Page 16');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ReqPlanDelete', 18, 'Use the Delete plan process to delete the current scheduling results in the selected plan. Only the data (requirements and planned orders) are deleted not the plan itself or the configuration of the plan.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ReqCalc\insertItemSched', 18, 'The INVENTSUMLOGTTS table is used for two purposes, 1) as part of the Inventory Multi Transaction System in order to roll back unsuccessful transactions, 2) allows Master scheduling to do an update based on changes to the on hand.   After the update, the records are deleted by Master scheduling.  

When a customer is registered for Master planning but does not use Master scheduling, this table will continue to grow and will never get cleared out.   Running Master scheduling will automatically clear the contents of this table.  

If you are registered for Master planning but are not running Master scheduling, you can manually purge the table through SQL with the following statement. 

DELETE INVENTSUMLOGTTS WHERE ISCOMMITTED =1');


insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ProdTableCleanUp', 19, 'Use the Production orders clean up process to delete production orders with the status of Ended. They are cost-accounted up to and including the date selected in the calendar.  It is good practice to clean up production orders with the status of Ended after a period of time.  
By running this process, it will also reduce the size of the database as well as improve querying on the Production forms');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ProdJournalCleanUp', 20, 'Use the Production journals clean up process to delete production journals. This function is especially useful when you upgrade to new versions of Microsoft Dynamics AX and there is less demand on system resources.  ');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\JmgCleanupTermReg and \Classes\JmgArchiveFutureRegistrations', 21, 'Use the Clean up registrations process to remove registrations from the raw registrations archive table.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\JmgArchiveFutureRegistrations', 21, 'Use the Archive future registrations process to remove future registrations from the raw registrations table.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\HRMAbsenceDeleteTables', 22, 'Use the Delete absence journals process to delete all empty journals that have not been transferred for approval. The exceptions to this rule are empty journals that contain a period that is before a journal that contains planned, or future, absences. If planned absences exist in a future period but you still want to delete the journal, you can cancel approval and then repeat the delete journal procedure. ');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\KMActionDelete', 22, 'Use the Delete actions process to delete actions and any responses.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\HRMDeleteEmployee', 22, 'Use the Delete personal information on employee process to delete personal information related for Employees whose affiliation with the company has been terminated.

It is important to remember that all affiliations with the line organization for the employees must be ended before the deletion process can be completed.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\HRMDeleteApplicant', 22, 'Use the Delete personal information on applicant process to delete personal information related for Applicants whose application for employment is no longer relevant.

It is important to remember that all applications for the applicant must have the status Rejected, Employed, or Canceled before the deletion process can be completed.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\KMKnowledgeCollectorDeleteResults', 23, 'Use the Delete results process to delete questionnaire results.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ProjJournalCleanUp', 24, 'Use the Project journals clean up process to delete a forecast model or delete specific transaction types from a model. ');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ProjForecastBudgetDelete', 24, 'Use the Delete budget process to delete a forecast model or delete specific transaction types from a model. ');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\ProjControlPeriodDelete', 24, 'Use the Delete process to delete estimates for a given estimate date.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\SalesQuotationDelete', 24, 'Use the Delete quotations process to delete multiple quotations at the same time.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\SMAServiceFunction_Delete', 25, 'Use the Delete service orders process to delete service orders.  You can delete a service order only if the service order allows for it');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\WorkCalendarDelete', 26, 'Use the Calendar cleanup process to specify the end date for deleting old working times. All old working hours up to, but not including, this date are deleted.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\BatchDelete', 26, 'Use the Delete process within the Function button to set up criteria for deleting a group of batch jobs.  You can delete batches by Hold, Waiting, Executing, Error, or Finished status');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\BatchStatus', 26, 'Use the Batch clean up process to clean up batches with a status of Ended');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Classes\AifMessageManager', 26, 'Use the Clear document XML process to clear all versions, or clear only the interim versions of document XML for documents and messages that are displayed on the Overview tab.

Use the Clear document history process to delete all messages, documents, and document correlations for messages that have a status of Processed or Error.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Forms\SysUserLog\Designs\Design\[ButtonGroup:ButtonGroup]\MenuItemButton:SysUserLogCleanUp\Methods\clicked', 27, 'Use the User log clean up process to delete information in the User log. You can also set up a regular batch job to clean up the user log.  You Can batch the job to delete with the parameter History Limit (days)');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Forms\SysDatabaseLog\Designs\Design\[ButtonGroup:ButtonGroup]\MenuItemButton:CleanUp\Methods\clicked', 27, 'Use the Database log clean up process to delete information in the Database log.');

insert into DATA_PURGE_CLASS (AX_Version, Class_Name, page, Description) values
('AX2009', '\Forms\SysTraceSQL\Designs\Design\[ButtonGroup:ButtonGroup]\[MenuButton:Functions]\MenuItemButton:SysTraceSQLClearLog\Methods\clicked', 27, 'Deletes all the SQL statement traces and query plans saved.');

------------------------------------------------------
-- Initialization of DATA_PURGE_TABLE
------------------------------------------------------

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'LedgerJournalTable', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'LedgerJournalTrans', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'LedgerJournalTransAccrual', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'LedgerJournalTransAccrualTrans', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'CustVendPaymJournalFee', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'AssetBookTableDerivedJournal', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'AssetDepBookTableDerivedJour', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'TaxWorkRegulation', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'VendTransCashDisc', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'LedgerJournalTrans_Project', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'LedgerJournalTrans_Asset', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'VendInvoiceInfo', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SpecTrans', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'TaxWithholdTrans', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'CustVendCreditInvoicingTable', 'General Ledger | Periodic | Clean up | Ledger journals clean up', '\Classes\LedgerJournalCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesParmTable', 'Accounts Receivable | Periodic | Clean up | Sales update history clean up','Accounts Receivable | Periodic | Clean up | Sales update history clean up');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesParmUpdate', 'Accounts Receivable | Periodic | Clean up | Sales update history clean up','Accounts Receivable | Periodic | Clean up | Sales update history clean up');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesParmSubTable', 'Accounts Receivable | Periodic | Clean up | Sales update history clean up','Accounts Receivable | Periodic | Clean up | Sales update history clean up');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesParmLine', 'Accounts Receivable | Periodic | Clean up | Sales update history clean up','Accounts Receivable | Periodic | Clean up | Sales update history clean up');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesParmSubLine', 'Accounts Receivable | Periodic | Clean up | Sales update history clean up','Accounts Receivable | Periodic | Clean up | Sales update history clean up');


insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesOrderEntryStatistics', 'Accounts Receivable | Periodic | Clean up | Order entry statistics clean up', '\Classes\SalesOrderEntryStatisticsCleanUp');



insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesLine', 'Account Receivable | Setup | Parameters | Update |Delete order line invoiced in total & Delete order after invoicing', 'Description_SalesLine');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'SalesTable', 'Account Receivable | Setup | Parameters | Update |Delete order line invoiced in total & Delete order after invoicing', 'Description_SalesLine');



insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchParmTable', 'Accounts Payable | Periodic | Clean up| Purchase update history clean up', '\Classes\PurchParmCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchParmUpdate', 'Accounts Payable | Periodic | Clean up| Purchase update history clean up', '\Classes\PurchParmCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchParmSubTable', 'Accounts Payable | Periodic | Clean up| Purchase update history clean up', '\Classes\PurchParmCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchParmLine', 'Accounts Payable | Periodic | Clean up| Purchase update history clean up', '\Classes\PurchParmCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchParmSubLine', 'Accounts Payable | Periodic | Clean up| Purchase update history clean up', '\Classes\PurchParmCleanUp');


insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchLine', 'Account Payable | Setup | Parameters | Update |Delete purchase order line invoiced in total & Delete purchase after invoicing','Description_Purchline');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'PurchTable', 'Account Payable | Setup | Parameters | Update |Delete purchase order line invoiced in total & Delete purchase after invoicing','Description_Purchline');


insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'InventJournalTable', 'Inventory Management | Periodic | Clean up | Inventory journals clean up', '\Classes\InventJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'InventJournalTrans', 'Inventory Management | Periodic | Clean up | Inventory journals clean up', '\Classes\InventJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'InvenJournalTrans_Tag', 'Inventory Management | Periodic | Clean up | Inventory journals clean up', '\Classes\InventJournalCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'InventSettlement', 'Inventory Management | Periodic | Clean up | Inventory settlements clean up', '\Classes\InventCostCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'BOMCalcTable', 'Inventory Management |Script', 'Description_BOMCalcTable and BOMCalcTrans');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'BOMcCalcTran', 'Inventory Management |Script', 'Description_BOMCalcTable and BOMCalcTrans');


insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'ReqTrans', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqPlanDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'ReqTransCov', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqPlanDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'ReqPO', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqPlanDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'WrkCtrCapRes', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqPlanDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'ReqRoute', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqPlanDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
(
'AX2009', 'ReqRouteJob', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqPlanDelete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'InventSumLogTTS', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqCalc\insertItemSched');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'WrkCtrCapRes', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqCalc\insertItemSched');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ReqRoute', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqCalc\deleteSchedulingReferencesComplete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ReqRouteJob', 'Master Planning | Periodic\Master scheduling\Master plan', '\Classes\ReqCalc\deleteSchedulingReferencesComplete');


insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdTable', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdBOM', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdRoute', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdRouteJob', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'WrkCtrCapRes', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdCalcTrans', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalTable', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalBOM', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalProd', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalRoute', 'Production | Periodic | Clean up | Production orders clean up', '\Classes\ProdTableCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdTable', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdBOM', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdRoute', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdRouteJob', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'WrkCtrCapRes', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdCalcTrans', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalTable', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalBOM', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalProd', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProdJournalRoute', 'Production | Periodic | Clean up | Production journals clean up', ' \Classes\ProdJournalCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'JmgTermReg', 'Shop Floor Control | Periodic | Cleanup | Archive future registrations', '\Classes\JmgArchiveFutureRegistrations');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'JmgTermReqArchive', 'Shop Floor Control | Periodic | Cleanup | Archive future registrations', '\Classes\JmgArchiveFutureRegistrations');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'JmgTermReg', 'Shop Floor Control | Periodic | Cleanup | Clean up registrations', '\Classes\JmgCleanupTermReg');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'JmgTermReqArchive', 'Shop Floor Control | Periodic | Cleanup | Clean up registrations', '\Classes\JmgCleanupTermReg');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'HRMAbsenceTable', 'Human resources | Periodic | Clean up | Delete absence journals', '\Classes\HRMAbsenceDeleteTables');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'kmVirtualNetworkAnswerTable', 'Human resources | Periodic | Clean up | Delete actions', '\Classes\HRMAbsenceDeleteTables');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'kmAction', 'Human resources | Periodic | Clean up | Delete actions', '\Classes\HRMAbsenceDeleteTables');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'EmplTable', 'Human resources | Periodic | Clean up | Delete personal information on employee', '\Classes\HRMDeleteEmployee');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'DocuRef', 'Human resources | Periodic | Clean up | Delete personal information on employee', '\Classes\HRMDeleteEmployee');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'DocuRef', 'Human resources | Periodic | Clean up | Delete personal information on applicant', '\Classes\HRMDeleteApplicant');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'HRMApplicantTable', 'Human resources | Periodic | Clean up | Delete personal information on applicant', '\Classes\HRMDeleteApplicant');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'kmVirtualNetworkAnswerTable', 'Questionnaire | Periodic | Delete results', '\Classes\KMKnowledgeCollectorDeleteResults');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjJournalTable', 'Project | Periodic | Clean up | Project journals clean up', '\Classes\ProjJournalCleanUp');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastCost', 'Project | Periodic | Budget | Delete budget', 'Project | Periodic | Estimate | Delete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastEmpl', 'Project | Periodic | Budget | Delete budget', 'Project | Periodic | Estimate | Delete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'LedgerBudget', 'Project | Periodic | Budget | Delete budget', 'Project | Periodic | Estimate | Delete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastOnAcc', 'Project | Periodic | Budget | Delete budget', 'Project | Periodic | Estimate | Delete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastRevenue', 'Project | Periodic | Budget | Delete budget', 'Project | Periodic | Estimate | Delete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ForecastSales', 'Project | Periodic | Budget | Delete budget', 'Project | Periodic | Estimate | Delete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastCost', 'Project | Periodic | Estimate | Delete', '\Classes\ProjControlPeriodDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastEmpl', 'Project | Periodic | Estimate | Delete', '\Classes\ProjControlPeriodDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjForecastRevenue', 'Project | Periodic | Estimate | Delete', '\Classes\ProjControlPeriodDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ForecastSales', 'Project | Periodic | Estimate | Delete', '\Classes\ProjControlPeriodDelete');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'ProjTable', 'Project | Periodic | Estimate | Delete', '\Classes\ProjControlPeriodDelete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'SalesQuotationTable', 'Project | Periodic | Quotation update | Delete quotations', '\Classes\SalesQuotationDelete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'SMAServiceOrderTable', 'Service | Periodic | Delete service orders', '\Classes\SMAServiceFunction_Delete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'WorkCalendarDate', 'Basic | Periodic | Calendar cleanup', '\Classes\WorkCalendarDelete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'Batch', 'Basic | Inquiries| Batch list | Functions | Delete', '\Classes\BatchDelete');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'Batch', 'Basic | Inquiries | Batch list | Functions | Clean up', '\Classes\BatchStatus');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'AifDocumentLog','Basic | Periodic | Application Integration Framework | Document History | Clear Document History | Clear document XML','\Classes\AifMessageManager');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'AifCorrelation','Basic | Periodic | Application Integration Framework | Document History | Clear Document History | Clear document XML','\Classes\AifMessageManager');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009', 'AifMessageLog','Basic | Periodic | Application Integration Framework | Document History | Clear Document History | Clear document XML','\Classes\AifMessageManager');


insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009','SysUserLog','Administration | Inquiries | User log | Clean up','\Forms\SysUserLog\Designs\Design\[ButtonGroup:ButtonGroup]\MenuItemButton:SysUserLogCleanUp\Methods\clicked');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009','SysDatabaseLog','Administration | Inquiries | Database log | Clean up log','\Forms\SysDatabaseLog\Designs\Design\[ButtonGroup:ButtonGroup]\MenuItemButton:CleanUp\Methods\clicked');

insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009','SysTraceTable','Administration | Inquiries | Database | SQL Statement Trace Log | Functions | Clear log','\Forms\SysTraceSQL\Designs\Design\[ButtonGroup:ButtonGroup]\[MenuButton:Functions]\MenuItemButton:SysTraceSQLClearLog\Methods\clicked');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009','SysTraceTableSQL','Administration | Inquiries | Database | SQL Statement Trace Log | Functions | Clear log','\Forms\SysTraceSQL\Designs\Design\[ButtonGroup:ButtonGroup]\[MenuButton:Functions]\MenuItemButton:SysTraceSQLClearLog\Methods\clicked');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009','SysTraceTableSQLExecPlan','Administration | Inquiries | Database | SQL Statement Trace Log | Functions | Clear log','\Forms\SysTraceSQL\Designs\Design\[ButtonGroup:ButtonGroup]\[MenuButton:Functions]\MenuItemButton:SysTraceSQLClearLog\Methods\clicked');
insert into DATA_PURGE_TABLE (AX_Version, Table_Name, Path_Name, Class_Name) values 
('AX2009','SysTraceTableSQLTabRef','Administration | Inquiries | Database | SQL Statement Trace Log | Functions | Clear log','\Forms\SysTraceSQL\Designs\Design\[ButtonGroup:ButtonGroup]\[MenuButton:Functions]\MenuItemButton:SysTraceSQLClearLog\Methods\clicked');




