-------------------------
-- AX 2012 PERF REVIEW
-------------------------

--Important note: the scripts below are validated with data collected by Performance Analyzer for Dynamics v1.16
--this tool can be downloaded from here http://archive.msdn.microsoft.com/DynamicsPerf/Release/ProjectReleases.aspx?ReleaseId=5954


---------------------------------
-- 1 HARDWARE AND INFRASTRUCTURE
---------------------------------

--Storage System
USE DynamicsPerf
SELECT [Database_Name],
	   [Physical_Name]   
FROM SQL_DATABASEFILES_CURR_VW
WHERE [Database_Name] not in ('DynamicsPerf','master','tempdb','model','msdb')
ORDER BY [Database_Name]

USE DynamicsPerf
SELECT [Database_Name],
	   [Physical_Name]   
FROM SQL_DATABASEFILES_CURR_VW
WHERE [Database_Name] = 'TempDB'


--Disk sector alignment
-- At the moment not stored in DynamicsPerf !!!!


--File allocation unit size
-- At the moment not stored in DynamicsPerf !!!!


-- Most of the hardware performance data is not stored in DynamicsPerf. Perfmon and PAL are the main tools here
-- However there is Page Life Expectancy and IO Statistics to get indication on memory pressure and possible disk bottlenecks


--Page Life Expectancy
USE DynamicsPerf
SELECT RUN_NAME, Page_Life_Expectancy
FROM   SERVERINFO


-- Virtual files IO Statistics
USE DynamicsPerf
SELECT STATS_TIME, DATABASE_NAME,FILE_ID, 
MSPerwrite = 
case num_of_writes
when 0 then NULL
ELSE

    (io_stall_write_ms  /  num_of_writes )
END,

 MSPerRead = 
 case num_of_Reads
when 0 then NULL
ELSE

    (io_stall_read_ms  /  num_of_reads )
END,
  
 (io_stall_write_ms + io_stall_read_ms) / ( num_of_reads + num_of_writes ) as MsPerIo ,
       num_of_reads, num_of_bytes_read, io_stall_read_ms, num_of_writes, 
       num_of_bytes_written, io_stall_write_ms, io_stall,size_on_disk_bytes
FROM DISKSTATS_VW
where DATABASE_NAME in ('DynamicsAXPRDUPG','TempDB')


-------------------------
-- 2 SETUP AND SETTINGS
-------------------------

--SQL Server Setup
----------------------


-- SQL Server build
USE DynamicsPerf
SELECT DISTINCT SQL_VERSION
FROM STATS_COLLECTION_SUMMARY


-- Multiple SQL Server instances, multiple databases
USE DynamicsPerf
SELECT DATABASE_NAME,
       SUM(SIZE_MB) as SIZEMB
FROM   BUFFER_DETAIL_CURR_VW
WHERE  DATABASE_NAME <> 'DynamicsPerf'
GROUP  BY DATABASE_NAME
ORDER  BY SIZEMB DESC


-- Named pipes protocol
-- At the moment not stored in DynamicsPerf !!!!


-- SQL Server collation
USE DynamicsPerf
SELECT 
         DATABASE_NAME
       , collation_name 
FROM SQL_DATABASES_CURR_VW
WHERE  DATABASE_NAME <> 'DynamicsPerf'


-- TempDB sizing
USE DynamicsPerf
SELECT
         [DATABASE_NAME]
       , [FILE_NAME]
       , [PHYSICAL_NAME]
       , [FILE_TYPE]
       , [DB_SIZE(MB)]
       , [DB_FREE(MB)]
       , [FREE_SPACE_%]
       , [GROWTH_UNITS]
       , [GROW_MAX_SIZE(MB)]
FROM SQL_DATABASEFILES_CURR_VW
WHERE [DATABASE_NAME] = 'tempdb'
ORDER BY [DATABASE_NAME], [FILE_TYPE], [FILE_NAME]


--SQL Server Settings
----------------------

-- CPU and Priority Boost
USE DynamicsPerf
SELECT name,minimum,maximum,config_value,run_value
FROM SQL_CONFIGURATION_CURR_VW
WHERE name in ('priority boost','affinity64 mask','affinity64 I/O mask','affinity mask','affinity I/O mask')


--Max degree of parallelism
USE DynamicsPerf
SELECT name,minimum,maximum,config_value,run_value
FROM SQL_CONFIGURATION_CURR_VW
WHERE name = 'max degree of parallelism'


--SQL Server Trace flags
USE DynamicsPerf
SELECT * FROM TRACEFLAGS T
WHERE		T.STATS_TIME = 
	(
		SELECT MAX(STATS_TIME)
		FROM STATS_COLLECTION_SUMMARY
	)


--AWE enabled <remove this check for x64 SQL Server>
USE DynamicsPerf
SELECT name,minimum,maximum,config_value,run_value
FROM SQL_CONFIGURATION_CURR_VW
WHERE name = 'AWE enabled'


--Max server memory
USE DynamicsPerf
SELECT name,minimum,maximum,config_value,run_value
FROM   SQL_CONFIGURATION_CURR_VW
WHERE name = 'max server memory (MB)' or name = 'min server memory (MB)'
ORDER BY name


--Fill factor
USE DynamicsPerf
SELECT name,minimum,maximum,config_value,run_value
FROM SQL_CONFIGURATION_CURR_VW
WHERE name = 'fill factor (%)'




-- Recovery model
USE DynamicsPerf
SELECT   database_name
       , database_id  
       , recovery_model
       , recovery_model_desc
FROM SQL_DATABASES_CURR_VW
WHERE  database_name  not in ('DynamicsPerf','master','tempdb','model','msdb')


-- Compatibility level
USE DynamicsPerf
SELECT   database_name
       , database_id 
       , compatibility_level
FROM SQL_DATABASES_CURR_VW
WHERE  database_name  not in ('DynamicsPerf','master','tempdb','model','msdb')


-- Read Committed Snapshot
USE DynamicsPerf
SELECT   database_name
       , database_id 
       , is_read_committed_snapshot_on 
FROM SQL_DATABASES_CURR_VW
WHERE  database_name  not in ('DynamicsPerf','master','tempdb','model','msdb')


-- Auto create and update statistics
USE DynamicsPerf
SELECT   database_name
       , database_id 
       , is_auto_create_stats_on
       , is_auto_update_stats_on
       , is_auto_update_stats_async_on  
FROM SQL_DATABASES_CURR_VW
WHERE  database_name  not in ('DynamicsPerf','master','tempdb','model','msdb')


-- Autogrowth
USE DynamicsPerf
SELECT
         [DATABASE_NAME]
       , [FILE_NAME]
       , [FILE_TYPE]
       , [DB_SIZE(MB)]
       , [DB_FREE(MB)]
       , [FREE_SPACE_%]
       , [GROWTH_UNITS]
       , [GROW_MAX_SIZE(MB)]
FROM SQL_DATABASEFILES_CURR_VW
WHERE [DATABASE_NAME] not in ('DynamicsPerf','master','tempdb','model','msdb')
ORDER BY [DATABASE_NAME], [FILE_TYPE], [FILE_NAME]


-- SQL Server TokenAndPermUserStore
USE DynamicsPerf
SELECT RUN_NAME, [CURRENTSIZEOFTOKENCACHE(KB)]
FROM   SERVERINFO
ORDER BY STATS_TIME DESC

-- Instant file initialization
-- At the moment not stored in DynamicsPerf !!!!


-- Lock pages in memory
-- At the moment not stored in DynamicsPerf !!!!





-- SQL Server Maintenance
------------------------
USE DynamicsPerf
SELECT *
FROM   SQL_JOBS_CURR_VW


--check current fragmentation
USE [DynamicsPerf]
DECLARE @date datetime
SET @date = '2013-04-15 22:41:00.000' -- add stats date here
SELECT a.STATS_TIME, a.OBJECT_ID, a.INDEX_ID, b.TABLE_NAME, b.INDEX_NAME, b.INDEX_DESCRIPTION, b.ROW_COUNT, b.PAGE_COUNT, a.AVG_FRAGMENTATION_IN_PERCENT 
FROM index_physical_stats a  
JOIN index_detail AS b
	ON a.object_id = b.object_id and a.INDEX_ID = b.INDEX_ID
WHERE B.STATS_TIME = @date and 
a.STATS_TIME = @date and
a.AVG_FRAGMENTATION_IN_PERCENT > 30 and 
INDEX_DESCRIPTION <> 'HEAP' and 
PAGE_COUNT > 500
ORDER BY a.AVG_FRAGMENTATION_IN_PERCENT desc


-- Dynamics AX AOS setup
------------------------

-- Dynamics AX build
USE DynamicsPerf
SELECT TOP 1 DYNAMICS_VERSION as 'AX version'
FROM dbo.STATS_COLLECTION_SUMMARY
ORDER BY STATS_TIME DESC

USE DynamicsPerf
SELECT DISTINCT SERVER_NAME as 'AOS server name', substring(MESSAGE,185,30) as 'AX Kernel build'
FROM AOS_EVENTLOG
WHERE EVENT_CODE = 149


-- Multiple AOS instances
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
GROUP BY SERVER_NAME, AOS_INSTANCE_NAME
HAVING COUNT(*) > 1
ORDER BY SERVER_NAME

-- AX2012: Check if multiple AOS instances per server and affinity is not set,or is set to overlapping CPUs
SELECT A1.SERVER_NAME, 
A1.AOS_INSTANCE_NAME		AS '1st Instance Name', 
B1.AOS_INSTANCE_NAME		AS '2nd Instance Name', 
'1st Instance Affinity' = 
	CASE
		WHEN A2.SETTING_VALUE IS NULL 	THEN 'All'	-- If reg key missing then affinity not set
		ELSE	A2.SETTING_VALUE					-- Display affinity mask				
	END,
'2nd Instance Affinity' = 
	CASE
		WHEN B2.SETTING_VALUE IS NULL 	THEN 'All'	-- If reg key missing then affinity not set
		ELSE	B2.SETTING_VALUE					-- Display affinity mask			
	END,
Message = 
	CASE
		WHEN B1.AOS_INSTANCE_NAME IS NOT NULL AND 
			(A2.SETTING_VALUE IS NULL OR  B2.SETTING_VALUE IS NULL)
			THEN 'Warning - Multiple Instances and at Least 1 Processor Affinity not Set'
		WHEN B1.AOS_INSTANCE_NAME IS NOT NULL AND 
			(CONVERT(INT,A2.SETTING_VALUE) & CONVERT(INT,B2.SETTING_VALUE)) <> 0
			THEN 'Warning - Multiple Instances and Processor Affinities Overlap CPUs'
		ELSE 'OK'
	END
FROM AOS_REGISTRY A1
LEFT JOIN AOS_REGISTRY A2
ON	A2.SERVER_NAME = A1.SERVER_NAME 
AND	A2.AOS_INSTANCE_NAME		= A1.AOS_INSTANCE_NAME 
AND	A2.AOS_CONFIGURATION_NAME = A1.AOS_CONFIGURATION_NAME 
AND	A2.SETTING_NAME = 'processaffinitymask' 
LEFT JOIN  AOS_REGISTRY B1
ON	B1.SERVER_NAME = A1.SERVER_NAME 
AND	B1.AOS_INSTANCE_NAME <> A1.AOS_INSTANCE_NAME 
AND B1.IS_CONFIGURATION_ACTIVE = 'Y'
AND B1.SETTING_NAME = 'directory'
LEFT JOIN AOS_REGISTRY B2
ON	B2.SERVER_NAME = B1.SERVER_NAME 
AND	B2.AOS_INSTANCE_NAME		= B1.AOS_INSTANCE_NAME 
AND	B2.AOS_CONFIGURATION_NAME = B1.AOS_CONFIGURATION_NAME 
AND	B2.SETTING_NAME = 'processaffinitymask' 
WHERE A1.IS_CONFIGURATION_ACTIVE = 'Y'
AND A1.SETTING_NAME = 'directory'
ORDER BY SERVER_NAME

-- Maximum batch threads
USE DynamicsPerf
SELECT [SERVERID]
      ,[MAX_CLIENT_SESSIONS]
      ,[MAX_BATCH_THREADS]
      ,[BATCH_SERVER_START_TIME]
      ,[BATCH_SERVER_STOP_TIME]
FROM [DynamicsPerf].[dbo].[AX_SERVER_CONFIGURATION_VW]
WHERE IS_BATCH_ENABLED = 'YES'
ORDER BY SERVERID


-- Dynamics AX AOS settings
---------------------------

-- Index Hints and LTRIM
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'HINT'


-- Maximum buffer size
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'sqlbuffer'



-- Statement cache
-- Note: do not get confused here because the registry key 'opencursors' is used for 'system cache' setting in AX 2012
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'opencursors'


-- Debug Settings
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME IN ('xppdebug', 'globalbreakpoints')



-- Use of literals
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME LIKE '%literals%'



-- Data compression
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'compressionminsize'


-- Enable the hot-swapping of assemblies for each development session
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'hotswapenabled'


-- Generate ORDER BY clauses from WHERE clauses 
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'ignoredatasourceindex'


-- AOS Configuration commands
USE DynamicsPerf
SELECT SERVER_NAME, AOS_INSTANCE_NAME, SETTING_NAME, SETTING_VALUE
FROM AOS_REGISTRY 
WHERE IS_CONFIGURATION_ACTIVE = 'Y'
AND SETTING_NAME = 'extracmdline'


--Server Configuration  Performance Optimization
-- At the moment not stored in DynamicsPerf !!!!



-- Dynamics AX client settings
--------------------------------
-- Client performance options
-- At the moment not stored in DynamicsPerf !!!!



--Dynamics AX application setup
--------------------------------

-- AX companies
USE DynamicsPerf
SELECT DISTINCT
	DATAAREAID AS 'AX company'
FROM [AX_NUM_SEQUENCES_CURR_VW]
WHERE DATAAREAID <> 'dat'
ORDER BY DATAAREAID


-- Dynamics AX application settings
------------------------------------

-- Configuration keys SysDeletedObjects*
USE DynamicsPerf
SELECT TABLE_NAME, ROW_COUNT, INDEX_DESCRIPTION, INDEX_KEYS
FROM INDEX_STATS_CURR_VW
WHERE (INDEX_DESCRIPTION LIKE 'CLUSTERED%' OR INDEX_DESCRIPTION LIKE 'HEAP%')
AND TABLE_NAME like 'DEL_%'
ORDER BY ROW_COUNT DESC


-- Entire table cache
USE DynamicsPerf
SELECT DISTINCT A.TABLE_NAME, CACHE_LOOKUP, PAGE_COUNT
FROM	AX_TABLE_DETAIL_CURR_VW A,
		INDEX_STATS_CURR_VW I
WHERE	A.DATABASE_NAME = I.DATABASE_NAME
AND		A.TABLE_NAME = I.TABLE_NAME
AND		CACHE_LOOKUP = 'EntireTable'
AND		(INDEX_DESCRIPTION  = 'HEAP' OR INDEX_DESCRIPTION LIKE 'CLUSTERED%')
AND		PAGE_COUNT > 4  --change this value to the server configuration, performance optimization setting "Entire table cache size" (1 page = 8 KB)
ORDER BY PAGE_COUNT DESC

SELECT DISTINCT A.TABLE_NAME, CACHE_LOOKUP, USER_UPDATES
FROM	AX_TABLE_DETAIL_CURR_VW A,
		INDEX_STATS_CURR_VW I
WHERE	A.DATABASE_NAME = I.DATABASE_NAME
AND		PAGE_COUNT > 0
AND	    USER_UPDATES >= 50
AND		A.TABLE_NAME = I.TABLE_NAME
AND		CACHE_LOOKUP = 'EntireTable'
AND		(INDEX_DESCRIPTION  = 'HEAP' OR INDEX_DESCRIPTION LIKE 'CLUSTERED%')
ORDER BY USER_UPDATES DESC

-- this optional test can be used to find out tables that are currently not using entire table cache but could be a good candidate
USE DynamicsPerf
SELECT DISTINCT A.TABLE_NAME, CACHE_LOOKUP, USER_UPDATES, USER_LOOKUPS, PAGE_COUNT
FROM	AX_TABLE_DETAIL_CURR_VW A,
		INDEX_STATS_CURR_VW I
WHERE	A.DATABASE_NAME = I.DATABASE_NAME
AND		PAGE_COUNT < 16
AND		PAGE_COUNT > 0
AND	    USER_UPDATES <= 50
AND		A.TABLE_NAME = I.TABLE_NAME
AND		CACHE_LOOKUP <> 'EntireTable'
AND		(INDEX_DESCRIPTION  = 'HEAP' OR INDEX_DESCRIPTION LIKE 'CLUSTERED%')
ORDER BY USER_LOOKUPS DESC


-- Record cache
USE DynamicsPerf
SELECT I.TABLE_NAME, AXTD.CACHE_LOOKUP
from INDEX_STATS_CURR_VW I
	INNER JOIN AX_TABLE_DETAIL_CURR_VW AXTD
	  ON I.TABLE_NAME = AXTD.TABLE_NAME
WHERE AXTD.CACHE_LOOKUP <> 'None' AND AXTD.CACHE_LOOKUP <> 'EntireTable'
	AND I.TABLE_NAME NOT IN
	  (SELECT DISTINCT I2.TABLE_NAME
	   FROM INDEX_STATS_CURR_VW I2
	   WHERE I2.INDEX_DESCRIPTION LIKE '%UNIQUE%')
GROUP BY I.TABLE_NAME, AXTD.CACHE_LOOKUP
ORDER BY I.TABLE_NAME

--Record cache excluding DEL_xxx
SELECT I.TABLE_NAME, AXTD.CACHE_LOOKUP
from INDEX_STATS_CURR_VW I
INNER JOIN AX_TABLE_DETAIL_CURR_VW AXTD
ON I.TABLE_NAME = AXTD.TABLE_NAME
WHERE AXTD.CACHE_LOOKUP <> 'None' AND AXTD.CACHE_LOOKUP <> 'EntireTable'
AND I.TABLE_NAME NOT LIKE 'DEL_%'
AND I.TABLE_NAME NOT IN
(SELECT DISTINCT I2.TABLE_NAME 
FROM INDEX_STATS_CURR_VW I2
WHERE I2.INDEX_DESCRIPTION LIKE '%UNIQUE%')
GROUP BY I.TABLE_NAME, AXTD.CACHE_LOOKUP
ORDER BY I.TABLE_NAME


--Number sequences
USE DynamicsPerf
SELECT DISTINCT
	DATAAREAID AS 'AX company',
	(SELECT COUNT(*) FROM [AX_NUM_SEQUENCES_CURR_VW] NT1 WHERE NT.DATAAREAID = NT1.DATAAREAID AND NT1.NEXTREC > 0 GROUP BY NT1.DATAAREAID) AS 'In use',
	(SELECT COUNT(*) FROM [AX_NUM_SEQUENCES_CURR_VW] NT2 WHERE NT.DATAAREAID = NT2.DATAAREAID AND NT2.CONTINUOUS = 1 AND NT2.NEXTREC > 0 GROUP BY NT2.DATAAREAID) AS 'Continuous',
	(SELECT COUNT(*) FROM [AX_NUM_SEQUENCES_CURR_VW] NT3 WHERE NT.DATAAREAID = NT3.DATAAREAID AND NT3.CONTINUOUS = 0 AND NT3.NEXTREC > 0 GROUP BY NT3.DATAAREAID) AS 'Non continuous',
	(SELECT COUNT(*) FROM [AX_NUM_SEQUENCES_CURR_VW] NT4 WHERE NT.DATAAREAID = NT4.DATAAREAID AND NT4.CONTINUOUS = 0 AND NT4.FETCHAHEAD <> 0 AND NT4.NEXTREC > 0 GROUP BY NT4.DATAAREAID) AS 'Pre-allocation'
FROM [AX_NUM_SEQUENCES_CURR_VW] NT


-- Run this to get the run_name value you need in the next 3 queries about number sequences. 
-- Copy the Run_name value and insert in the range in the next queries. First and last Run_Name
USE DynamicsPerf
SELECT DISTINCT RUN_NAME, STATS_TIME from AX_NUM_SEQUENCES_VW
ORDER BY STATS_TIME


-- Top 10 of Continuous Number Sequences
USE DynamicsPerf
SELECT TOP 10 --RUN2.[DATABASE_NAME],
       RUN2.[DATAAREAID],
       RUN2.[NUMBERSEQUENCE],
       RUN2.[TXT],
       DATEDIFF(hh,RUN1.STATS_TIME, RUN2.STATS_TIME) AS ELAPSED_HOURS,
       RUN2.NEXTREC - RUN1.NEXTREC AS TOTAL_NUMBERS_CONSUMED,
       (RUN2.NEXTREC - RUN1.NEXTREC)/(DATEDIFF(hh,RUN1.STATS_TIME, RUN2.STATS_TIME)) AS AVG_HOURLY_CONSUMPTION_RATE,
          RUN1.STATS_TIME AS FIRST_SAMPLE_DATE_TIME,
          RUN2.STATS_TIME AS SECOND_SAMPLE_DATE_TIME
       --,RUN2.[CONTINUOUS]
       --,RUN2.[FETCHAHEAD]
       --,RUN2.[FETCHAHEADQTY]
       --,RUN2.[FORMAT]
FROM   [AX_NUM_SEQUENCES_VW] RUN1
       INNER JOIN [AX_NUM_SEQUENCES_VW] RUN2
         ON RUN1.NUMBERSEQUENCE = RUN2.NUMBERSEQUENCE
            AND RUN1.DATAAREAID = RUN2.DATAAREAID
WHERE  RUN1.RUN_NAME = 'Sep 25 2012  9:00PM' --enter run name of first sample here (see STATS_COLLECTION_SUMMARY)
       AND RUN2.RUN_NAME = 'Oct  1 2012  9:00PM' --enter run name of second sample here  (see STATS_COLLECTION_SUMMARY)
       AND RUN2.[CONTINUOUS] = 1
ORDER BY 6 DESC


-- number of Non_Continuous Number Sequences with a Pre-allocation Quantity different from 0
USE Dynamicsperf
SELECT COUNT(*) as 'number sequences using pre-allocation'
FROM   [AX_NUM_SEQUENCES_VW] RUN1
       INNER JOIN [AX_NUM_SEQUENCES_VW] RUN2
         ON RUN1.NUMBERSEQUENCE = RUN2.NUMBERSEQUENCE
            AND RUN1.DATAAREAID = RUN2.DATAAREAID
WHERE  RUN1.RUN_NAME = 'Sep 25 2012  9:00PM' --enter run name of first sample here (see STATS_COLLECTION_SUMMARY)
       AND RUN2.RUN_NAME = 'Oct  1 2012  9:00PM' --enter run name of second sample here  (see STATS_COLLECTION_SUMMARY)
       AND ((RUN2.[CONTINUOUS] = 0) AND (RUN2.FETCHAHEADQTY <> 0))

-- Top 10 of Non-Continuous Number Sequences with a Pre-allocation Quantity of 0
USE DynamicsPerf
SELECT TOP 10 --RUN2.[DATABASE_NAME],
       RUN2.[DATAAREAID],
       RUN2.[NUMBERSEQUENCE],
       RUN2.[TXT],
       DATEDIFF(hh,RUN1.STATS_TIME, RUN2.STATS_TIME) AS ELAPSED_HOURS,
       RUN2.NEXTREC - RUN1.NEXTREC AS TOTAL_NUMBERS_CONSUMED,
       (RUN2.NEXTREC - RUN1.NEXTREC)/(DATEDIFF(hh,RUN1.STATS_TIME, RUN2.STATS_TIME)) AS AVG_HOURLY_CONSUMPTION_RATE,
          RUN1.STATS_TIME AS FIRST_SAMPLE_DATE_TIME,
          RUN2.STATS_TIME AS SECOND_SAMPLE_DATE_TIME
       --,RUN2.[CONTINUOUS]
       --,RUN2.[FETCHAHEAD]
       --,RUN2.[FETCHAHEADQTY]
       --,RUN2.[FORMAT]
FROM   [AX_NUM_SEQUENCES_VW] RUN1
       INNER JOIN [AX_NUM_SEQUENCES_VW] RUN2
         ON RUN1.NUMBERSEQUENCE = RUN2.NUMBERSEQUENCE
            AND RUN1.DATAAREAID = RUN2.DATAAREAID
WHERE  RUN1.RUN_NAME = 'Sep 25 2012  9:00PM' --enter run name of first sample here (see STATS_COLLECTION_SUMMARY)
       AND RUN2.RUN_NAME = 'Oct  1 2012  9:00PM' --enter run name of second sample here  (see STATS_COLLECTION_SUMMARY)
       AND ((RUN2.[CONTINUOUS] = 0) AND (RUN2.FETCHAHEADQTY = 0)) 
ORDER BY 6 DESC

-- Top 10 of most active Number sequences
USE DynamicsPerf
SELECT TOP 10 RUN2.[DATAAREAID] AS 'AX company',
       RUN2.[NUMBERSEQUENCE] AS 'Number sequence',
       RUN2.[TXT] AS 'Description',
       DATEDIFF(hh,RUN1.STATS_TIME, RUN2.STATS_TIME) AS 'Elapsed hours',
       RUN2.NEXTREC - RUN1.NEXTREC AS 'Total Numbers consumed',
       (RUN2.NEXTREC - RUN1.NEXTREC)/(DATEDIFF(hh,RUN1.STATS_TIME, RUN2.STATS_TIME)) AS 'Avg. hourly consumption rate',
      --    RUN1.STATS_TIME AS FIRST_SAMPLE_DATE_TIME,
      --    RUN2.STATS_TIME AS SECOND_SAMPLE_DATE_TIME,
       RUN2.[CONTINUOUS] as 'Continuous',
       RUN2.[FETCHAHEAD] as 'Pre-allocation',
       RUN2.[FETCHAHEADQTY] as 'number'
      --    RUN2.[FORMAT]
FROM   [AX_NUM_SEQUENCES_VW] RUN1
       INNER JOIN [AX_NUM_SEQUENCES_VW] RUN2
         ON RUN1.NUMBERSEQUENCE = RUN2.NUMBERSEQUENCE
            AND RUN1.DATAAREAID = RUN2.DATAAREAID
WHERE  RUN1.RUN_NAME = 'Sep 25 2012  9:00PM' --enter run name of first sample here (see STATS_COLLECTION_SUMMARY)
       AND RUN2.RUN_NAME = 'Oct  1 2012  9:00PM' --enter run name of second sample here  (see STATS_COLLECTION_SUMMARY)
ORDER BY 5 DESC


-- The following script only works if you run script Create NTEXT objects after the setup_AX2012.sql
-- Memo fields
USE DynamicsPerf
SELECT COUNT(*) AS 'ntext total' FROM dbo.AX_NTEXT_CURR_VW 
SELECT COUNT(*) AS 'ntext not in use' FROM dbo.AX_NTEXT_CURR_VW WHERE MAX_LENGTH = 0
SELECT COUNT(*) AS 'ntext in use' FROM dbo.AX_NTEXT_CURR_VW WHERE MAX_LENGTH > 0
SELECT COUNT(*) AS 'ntext > 0 and < 1000' FROM dbo.AX_NTEXT_CURR_VW WHERE MAX_LENGTH > 0 and MAX_LENGTH < 1000
SELECT COUNT(*) AS 'ntext >= 1000'FROM dbo.AX_NTEXT_CURR_VW WHERE MAX_LENGTH >= 1000

-- select all ntext > 0 and < 1000
USE DynamicsPerf
SELECT TABLE_NAME, COLUMN_NAME, MAX_LENGTH 
FROM dbo.AX_NTEXT_CURR_VW WHERE MAX_LENGTH > 0 and MAX_LENGTH < 1000
ORDER BY MAX_LENGTH DESC

-- select all ntext > 1000
USE DynamicsPerf
SELECT TABLE_NAME, COLUMN_NAME, MAX_LENGTH 
FROM dbo.AX_NTEXT_CURR_VW WHERE MAX_LENGTH > 1000
ORDER BY MAX_LENGTH DESC


-- Record Level Security
USE DynamicsPerf
SELECT TABLE_NAME, ROW_COUNT
FROM INDEX_STATS_CURR_VW
WHERE (INDEX_DESCRIPTION LIKE 'CLUSTERED%' OR INDEX_DESCRIPTION LIKE 'HEAP%')
AND TABLE_NAME = 'SYSRECORDLEVELSECURITY'



-------------------------
-- 3 CODE AND QUERIES
-------------------------

-- When was the SQL server last restarted
USE DynamicsPerf
SELECT DISTINCT SQL_server_starttime 
FROM STATS_COLLECTION_SUMMARY


-- Expensive queries
USE DynamicsPerf
SELECT TOP 10
      SQL_TEXT
	, QUERY_PLAN
	, TOTAL_ELAPSED_TIME
	, AVG_ELAPSED_TIME
	, AVG_LOGICAL_READS
	, EXECUTION_COUNT
	, RUN_NAME
FROM QUERY_STATS_VW 
WHERE EXECUTION_COUNT > 10
ORDER BY AVG_LOGICAL_READS DESC


-- AX long running queries
USE DynamicsPerf
SELECT    CONVERT(nvarchar,CREATED_DATETIME,101) AS CREATED_DATE
		, DATEPART (hh, CREATED_DATETIME) AS HOUR_OF_DAY
		, COUNT (CREATED_DATETIME) AS EXECUTION_COUNT
		, SUM (SQL_DURATION) AS TOTAL_DURATION
		, AVG (SQL_DURATION) AS AVERAGE_DURATION
FROM AX_SQLTRACE_VW
WHERE 
SQL_DURATION > 2000
and CREATED_DATETIME >= '09/25/2012'
GROUP BY CONVERT(nvarchar,CREATED_DATETIME,101), DATEPART (hh, CREATED_DATETIME)
ORDER BY CREATED_DATE, HOUR_OF_DAY

-- AX users that are executing most of the long running queries 
USE DynamicsPerf
SELECT	  AX_USER_ID
		, COUNT (SQL_DURATION) AS QUERY_COUNT
		, SUM (SQL_DURATION) AS TOTAL_DURATION
		, AVG (SQL_DURATION) AS AVERAGE_DURATION
FROM AX_SQLTRACE_VW
WHERE CREATED_DATETIME >= '09/25/2012' and
SQL_DURATION > 2000
GROUP BY AX_USER_ID
ORDER BY TOTAL_DURATION DESC

-- If we want to know which long running queries a specific AX user was executing
USE DynamicsPerf
SELECT TOP 100
		  CREATED_DATETIME
		, SQL_TYPE
		, SQL_TEXT
		, SQL_DURATION
		, CALL_STACK
		, AX_USER_ID 
		, ROWS_AFFECTED
		, ROW_SIZE
		, IS_LOBS_INCLUDED
		, ROWS_PER_FETCH
		, IS_SELECTED_FOR_UPDATE
FROM AX_SQLTRACE_VW
WHERE CREATED_DATETIME >= '09/25/2012' and
AX_USER_ID = 'AUSER'  -- change user name using the resultset of previous query
and SQL_DURATION > 2000
ORDER BY SQL_DURATION DESC

-- find the SQL query plan in the SQL Server query statistics 
USE DynamicsPerf
SELECT * FROM QUERY_STATS_VW 
WHERE SQL_TEXT LIKE '%SELECT T1.TRANSACTIONCURRENCYAMOUNT,T1.ACCOUNTINGCURRENCYAMOUNT,T1.REPORTINGCURRENCYAMOUNT,T1.QUANTITY,T1.ALLOCATIONLEVEL,T1.ISCORRECTION,T1.ISCREDIT,T1.TRANSACTIONCURRENCYCODE,T1.PAYMENTREFERENCE,T1.POSTINGTYPE,T1.LEDGERDIMENSION,T1.DEL_LEDGERTRANSREFRECID,T1.GENERALJOURNALENTRY,T1.DEL_DATAAREAID,T1.TEXT,T1.REASONREF,T1.PROJID_SA,T1.PROJTABLEDATAAREAID,T1.LEDGERACCOUNT,T1.CREATEDTRANSACTIONID,T1.RECVERSION,T1.RECID,T2.ACCOUNTINGDATE,T2.LEDGERENTRYJOURNAL,T2.ACKNOWLEDGEMENTDATE,T2.DEL_PERIODCODE,T2.LEDGERPOSTINGJOURNAL,T2.FISCALCALENDARPERIOD,T2.DEL_JOURNALNUMBER,T2.POSTINGLAYER,T2.LEDGER,T2.LEDGERPOSTINGJOURNALDATAAREAID,T2.DEL_DATAAREAID,T2.JOURNALNUMBER,T2.TRANSFERID,T2.BUDGETSOURCELEDGERENTRYPOSTED,T2.FISCALCALENDARYEAR,T2.SUBLEDGERVOUCHER,T2.SUBLEDGERVOUCHERDATAAREAID,T2.DOCUMENTDATE,T2.DOCUMENTNUMBER,T2.JOURNALCATEGORY,T2.DEL_VOUCHER,T2.CREATEDDATETIME,T2.CREATEDBY,T2.CREATEDTRANSACTIONID,T2.RECVERSION,T2.RECID,T3.DISPLAYVALUE,T3.DEL_COMBINATIONHASH1,T3.DEL_COMBINATIONHASH2,T3.DEL_COMBINATIONHASH3,T3.DEL_COMBINATIONHASH4,T3.DEL_COMBINATIONHASH5,T3.DEL_ACCOUNTNUM,T3.DEL_DIMENSION,T3.DEL_DIMENSION2_,T3.DEL_DIMENSION3_,T3.DEL_DIMENSION4_,T3.DEL_DIMENSION5_,T3.MAINACCOUNT,T3.ACCOUNTSTRUCTURE,T3.LEDGERDIMENSIONTYPE,T3.RECVERSION,T3.RECID,T4.DISPLAYVALUE,T4.RECID,T4.RECVERSION,T5.TRANSRECID,T5.SETTLEID,T5.SUBLEDGERJOURNALACCOUNTENTRY,T5.RECVERSION,T5.RECID,T6.ENDDATE,T6.DESCRIPTION,T6.MONTH,T6.QUARTER,T6.STARTDATE,T6.FISCALCALENDARYEAR,T6.SHORTNAME,T6.NAME,T6.TYPE,T6.FISCALCALENDAR,T6.MODIFIEDDATETIME,T6.MODIFIEDBY,T6.RECVERSION,T6.RECID,T7.VOUCHER,T7.VOUCHERDATAAREAID,T7.GENERALJOURNALENTRY,T7.ACCOUNTINGDATE,T7.RECVERSION,T7.RECID,T8.MAINACCOUNTID,T8.NAME,T8.CURRENCYCODE,T8.TYPE,T8.ACCOUNTCATEGORYREF,T8.DEBITCREDITPROPOSAL,T8.DEBITCREDITCHECK,T8.DEBITCREDITBALANCEDEMAND,T8.CLOSING,T8.EXCHANGEADJUSTED,T8.MONETARY,T8.MANDATORYPAYMENTREFERENCE,T8.VALIDATECURRENCY,T8.USERINFOID,T8.VALIDATEUSER,T8.POSTINGTYPE,T8.VALIDATEPOSTING,T8.SRUCODE,T8.CONSOLIDATIONMAINACCOUNT,T8.OFFSETLEDGERDIMENSION,T8.DEL_CONVERSIONPRINCIPLE,T8.MAINACCOUNTTEMPLATE,T8.LEDGERCHARTOFACCOUNTS,T8.INFLATIONADJUSTMENT_MX,T8.REPOMOTYPE_MX,T8.ADJUSTMENTMETHOD_MX,T8.TRANSFERYEARENDACCOUNT_ES,T8.OPENINGACCOUNT,T8.REPORTINGACCOUNTTYPE,T8.UNITOFMEASURE,T8.HOB_USECURRENCYREALACCOUNTS,T8.AVA_ALTADJUSTPOSTING,T8.RECVERSION,T8.RECID,T3.HASH FROM GENERALJOURNALACCOUNTENTRY T1 CROSS JOIN GENERALJOURNALENTRY T2 CROSS JOIN DIMENSIONATTRIBUTEVALUECOMBINATION T3 LEFT OUTER JOIN DIMENSIONATTRIBUTEVALUECOMBINATION T4 ON (T1.LEDGERDIMENSION=T4.RECID) LEFT OUTER JOIN LEDGERTRANSSETTLEMENT T5 %'  -- change query_text by (part of) the query you are searching for


-- Missing clustered indexes
USE DynamicsPerf
SELECT TABLE_NAME, (USER_SCANS + USER_LOOKUPS) AS LOOKUP_OR_SCAN_COUNT, ROW_COUNT, PAGE_COUNT
FROM INDEX_STATS_CURR_VW
WHERE INDEX_DESCRIPTION LIKE 'HEAP%' 
AND (USER_SCANS + USER_LOOKUPS) > 0
AND PAGE_COUNT > 64
AND ROW_COUNT > 1000
ORDER BY (USER_SCANS + USER_LOOKUPS) DESC

-- which heaps currently only have one non-clustered index 
USE DynamicsPerf
SELECT TABLE_NAME, (USER_SCANS + USER_LOOKUPS) AS LOOKUP_OR_SCAN_COUNT, ROW_COUNT, PAGE_COUNT
FROM INDEX_STATS_CURR_VW O
WHERE INDEX_DESCRIPTION LIKE 'HEAP%' 
AND (USER_SCANS + USER_LOOKUPS) > 0
AND PAGE_COUNT > 64
AND ROW_COUNT > 1000
AND 2 = 
(
	SELECT COUNT(*) FROM INDEX_STATS_VW I
	WHERE O.RUN_NAME = I.RUN_NAME
	AND O.TABLE_NAME = I.TABLE_NAME
)
ORDER BY (USER_SCANS + USER_LOOKUPS) DESC

-- we want to know which indexes a certain table currently has and how these indexes are used
USE DynamicsPerf
SELECT * FROM INDEX_STATS_CURR_VW 
WHERE TABLE_NAME = 'JM_ENTRATE_HISTORY'  --change table name
ORDER BY USER_SEEKS DESC

-- TOP 10 overview of expensive queries (ordered by total logical reads) that contain one or more table scans:
USE DynamicsPerf
SELECT TOP 10 SQL_TEXT, TOTAL_ELAPSED_TIME, AVG_ELAPSED_TIME, EXECUTION_COUNT, TOTAL_LOGICAL_READS 
FROM QUERY_STATS_CURR_VW 
WHERE QUERY_PLAN_TEXT LIKE '%TABLE SCAN%'
ORDER BY  TOTAL_LOGICAL_READS DESC


-- Forwarded fetch count
USE DynamicsPerf
SELECT DISTINCT TABLE_NAME, FORWARDED_FETCH_COUNT 
FROM INDEX_STATS_CURR_VW
WHERE FORWARDED_FETCH_COUNT > 1000
ORDER BY FORWARDED_FETCH_COUNT DESC


-- Left key subset indexes
USE DynamicsPerf
SELECT * 
FROM INDEX_STATS_CURR_VW O
WHERE INDEX_DESCRIPTION NOT LIKE '%UNIQUE%' 
AND EXISTS
	(
	SELECT * FROM INDEX_STATS_VW I
	WHERE I.RUN_NAME = O.RUN_NAME
	AND I.TABLE_NAME = O.TABLE_NAME
	AND I.INDEX_KEYS <> O.INDEX_KEYS
	AND I.INDEX_KEYS LIKE O.INDEX_KEYS + ',%'
	)
ORDER BY TABLE_NAME, INDEX_KEYS

-- Query to verify from which index these indexes are a left key subset 
USE DynamicsPerf
SELECT * FROM INDEX_STATS_CURR_VW
WHERE TABLE_NAME = 'JM_SHIPMENTITEM'  --change table name


-- RecVersion indexes
USE DynamicsPerf
SELECT TABLE_NAME, INDEX_KEYS
FROM INDEX_STATS_CURR_VW
WHERE INDEX_KEYS LIKE '%RECVERSION%'
ORDER BY TABLE_NAME, INDEX_KEYS	


-- Missing indexes
USE DynamicsPerf
SELECT TOP 10 SQL_TEXT, TOTAL_ELAPSED_TIME, AVG_ELAPSED_TIME, EXECUTION_COUNT, TOTAL_LOGICAL_READS, QUERY_PLAN 
FROM QUERY_STATS_VW 
WHERE QUERY_PLAN_TEXT LIKE '%MissingIndexes%'
ORDER BY EXECUTION_COUNT DESC


-- Hidden index scans
USE DynamicsPerf
SELECT TOP 10 SQL_TEXT, TABLE_NAME, INDEX_NAME, SEEK_COLUMNS, EXECUTION_COUNT, TOTAL_ELAPSED_TIME, TOTAL_WORKER_TIME, QUERY_PLAN
FROM HIDDEN_SCANS_VW
ORDER BY TOTAL_ELAPSED_TIME DESC


-- Not used indexes
USE DynamicsPerf
SELECT TABLE_NAME,
       INDEX_NAME,
       INDEX_DESCRIPTION,
       INDEX_KEYS,
       INCLUDED_COLUMNS,
       SUM(USER_SEEKS) AS USER_SEEKS,
       SUM(USER_SCANS) AS USER_SCANS,
       SUM(USER_LOOKUPS) AS USER_LOOKUPS,
       SUM(USER_UPDATES) AS USER_UPDATES
FROM INDEX_STATS_VW 
WHERE INDEX_DESCRIPTION NOT LIKE '%UNIQUE%' 
AND INDEX_DESCRIPTION NOT LIKE '%HEAP%' 
GROUP BY TABLE_NAME, INDEX_NAME, INDEX_DESCRIPTION, INDEX_KEYS, INCLUDED_COLUMNS
HAVING SUM(USER_SEEKS) = 0
AND SUM(USER_SCANS) = 0
AND SUM(USER_LOOKUPS) = 0
ORDER BY 9 DESC


-- Non-clustered index scans
USE DynamicsPerf
SELECT TOP 10 TABLE_NAME, INDEX_NAME, INDEX_DESCRIPTION, INDEX_KEYS, INCLUDED_COLUMNS, USER_SEEKS, USER_SCANS 
FROM INDEX_STATS_CURR_VW 
WHERE  USER_SCANS > 1000 AND USER_SCANS > USER_SEEKS
AND	INDEX_DESCRIPTION LIKE 'NONCLUSTERED%' 
ORDER BY USER_SCANS DESC

-- Dig deeper into the non-clustered index scans to find out queries and execution plans where the index is used. 
USE DynamicsPerf
SELECT TOP 100 * FROM QUERY_STATS_CURR_VW
WHERE  QUERY_PLAN_TEXT LIKE '%I_100260RECID%' -- change index name
ORDER BY  TOTAL_LOGICAL_READS DESC


---------------------------
-- 4 LOCKING AND BLOCKING
---------------------------

--Truncate BLOCKED_PROCESS_INFO tables and reset date BLOCKED_PROCESS_INFO_SETUP table
--To delete any historical data from previous (incorrect) load of blocking issues      
USE DynamicsPerf
TRUNCATE TABLE BLOCKED_PROCESS_INFO
TRUNCATE TABLE BLOCKED_PROCESS_INFO_SETUP
INSERT INTO BLOCKED_PROCESS_INFO_SETUP (LAST_COLLECTION_TIME) values('1/1/1900')

-- Load blocking information from SQL trace files with the following stored procedure 
-- Make sure to set the correct pathname in table DYNAMICSPERF_SETUP
USE DynamicsPerf
TRUNCATE TABLE DYNAMICSPERF_SETUP
INSERT INTO DYNAMICSPERF_SETUP (TRACE_FULL_PATH_NAME) values ('C:\DEMO files\DYNAMICS_DEFAULT.trc')

USE DynamicsPerf
EXEC SP_POPULATE_BLOCKED_PROCESS_INFO

--overview of all blocking occurences
USE DynamicsPerf
SELECT *
FROM   [BLOCKED_PROCESS_INFO_VW]
--WHERE WAIT_RESOURCE like '%72057652792721408%'
ORDER BY WAIT_TIME DESC


--overview of most blocked resources, how many time they occur, and max wait time in seconds
USE DynamicsPerf
SELECT DATABASE_NAME, substring(WAIT_RESOURCE,0,26) as WAIT_RESOURCE, COUNT(substring(WAIT_RESOURCE,0,26)) as OCCURENCE, MAX(WAIT_TIME)/1000 as 'MAX WAIT_TIME (sec)'
FROM   [BLOCKED_PROCESS_INFO_VW]
GROUP BY substring(WAIT_RESOURCE,0,26), DATABASE_NAME
ORDER BY COUNT(substring(WAIT_RESOURCE,0,26))DESC


--The following two queries can only be executed on the AX production environment to find object or index id of blocking statement:

--QUERY1: Select object name from object id
SELECT DISTINCT OBJECT_NAME(1641265102)
FROM master.sys.objects;
GO

--QUERY2: if it is not an OBJECT but KEY blocking, you can find the table and index by filling in the waitresource under hobt_id
SELECT o.name, i.name 
FROM sys.partitions p 
JOIN sys.objects o ON p.object_id = o.object_id 
JOIN sys.indexes i ON p.object_id = i.object_id 
AND p.index_id = i.index_id 
WHERE p.hobt_id = 72057594091077632  


--------------------------------
-- 5 DATA ARCHIVING AND CLEAN-UP
--------------------------------

-- top 25 tables by size (MB)
USE DynamicsPerf
SELECT TOP 25
	TABLE_NAME as 'Table Name', 
	ROW_COUNT as 'Number of rows',
	SUM(PAGE_COUNT) AS 'Data and Index pages', 
	((SUM(PAGE_COUNT) * 8)/1024) AS 'Data and Index space (MB)'
FROM INDEX_STATS_CURR_VW 
GROUP BY TABLE_NAME, ROW_COUNT
ORDER BY 'Data and Index pages' DESC

-- top 25 tables by number of rows
USE DynamicsPerf
SELECT TOP 25
	TABLE_NAME as 'Table Name', 
	ROW_COUNT as 'Number of rows',
	SUM(PAGE_COUNT) AS 'Data and Index pages', 
	((SUM(PAGE_COUNT) * 8)/1024) AS 'Data and Index space (MB)'
FROM INDEX_STATS_CURR_VW 
GROUP BY TABLE_NAME, ROW_COUNT
ORDER BY ROW_COUNT DESC

-- The following query only works if you first run the script CleanUP_Tables.sql written by jlnaro
-- Query Example using the DATA_PURGE objects
USE DynamicsPerf
Select distinct [TABLE NAME] as 'Table name', [ROW COUNT] as 'Number of rows', D.module_name as 'Module', D.path_name as 'Cleanup Action' from DATA_PURGE_VW D
JOIN
(
SELECT TOP 30
	IND.TABLE_NAME AS [TABLE NAME], IND.ROW_COUNT AS [ROW COUNT]
	, TOT.TOTAL_TABLE_AND_INDEX_SIZE_MB AS [TOTAL SIZE MB]
	-- , TOT.TOTAL_INDEX_AND_DATA_PAGES AS [TOTAL PAGES]
FROM INDEX_STATS_CURR_VW IND
JOIN
(SELECT TABLE_NAME, SUM(PAGE_COUNT) AS TOTAL_INDEX_AND_DATA_PAGES, 
	((SUM(PAGE_COUNT) * 8)/1024) AS TOTAL_TABLE_AND_INDEX_SIZE_MB 
	FROM INDEX_STATS_CURR_VW 
	GROUP BY TABLE_NAME
	) TOT
ON IND.TABLE_NAME = TOT.TABLE_NAME
WHERE (IND.INDEX_DESCRIPTION LIKE 'CLUSTERED%' OR IND.INDEX_DESCRIPTION LIKE 'HEAP%')
--ORDER BY ROW_COUNT DESC
 ORDER BY TOT.TOTAL_TABLE_AND_INDEX_SIZE_MB DESC ) L
 ON D.Table_Name = L.[TABLE NAME]
WHERE D.AX_Version = 'AX2009'  -- change version
order by [ROW COUNT] DESC

-- Run this to get the run_name values you need in the next  query about fastest growing tables
USE DynamicsPerf
SELECT DISTINCT RUN_NAME, STATS_TIME from AX_NUM_SEQUENCES_VW
ORDER BY STATS_TIME

--delta number of rows to find TOP 25 fastest growing tables
USE DynamicsPerf
SELECT TOP 25
	A.TABLE_NAME as 'Table Name', 
	A.ROW_COUNT as 'Number of rows begin',
	B.ROW_COUNT as 'Number of rows end',
	B.ROW_COUNT - A.ROW_COUNT as 'Number of rows delta'
	FROM INDEX_STATS_VW A, INDEX_STATS_VW B
WHERE A.TABLE_NAME = B.TABLE_NAME and A.RUN_NAME = 'Sep 25 2012  9:00PM' -- fill in first run_name here 
and B.RUN_NAME = 'Oct  1 2012  9:00PM' -- fill in last run_name here
GROUP BY A.TABLE_NAME, A.ROW_COUNT, B.ROW_COUNT
ORDER BY 'number of rows delta' DESC



